/*= R&S ESCI EMI Test Receiver Include File =================================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __RSESCI_HEADER
#define __RSESCI_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= RSIB interface support ==================================================*/
/*                                                                           */
/* The RSIB interface is a R&S defined protocol for remote control of R&S    */
/* spectrum and network analyzers. In addition to the standard VISA          */
/* attributes, the RSIB passport supports the following manufacturer specific*/
/* attributes:                                                               */
/*                                                                           */
/*****************************************************************************/
#ifndef __RSVIRSIB_H__

#define RS_ATTR_RSIB_SRE     (0x3FFC0001UL)     /* Switch a device to local or remote */
#define RS_ATTR_RSIB_LOC     (0x3FFC0002UL)     /* Switch a device temporarily to local */
#define RS_ATTR_RSIB_VER     (0x3FFC0003UL)     /* Passport Release Version */

#endif /* __RSVIRSIB_H__ */

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                     (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                       (_VI_ERROR+0x3FFC0900L)

#define RSESCI_ERROR_INSTRUMENT_ERROR               (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define RSESCI_ERROR_INVALID_CONFIGURATION          (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSESCI_ERROR_INSTRUMENT_OPTION              (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSESCI_ERROR_INSTRUMENT_DATA_NOT_AVAILABLE  (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSESCI_ERROR_SETTINGS_CONFLICT              (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSESCI_WARNING_SMALL_BUFFER                 (VI_WARNING_INSTR_OFFSET + 0xF5L)
#define RSESCI_ERROR_INSTRUMENT_NSUP_MODEL          (VI_ERROR_INSTR_OFFSET + 0xF6L)
#define RSESCI_ERROR_INSTRUMENT_IQ_OVERLOAD         (VI_ERROR_INSTR_OFFSET + 0xF7L)

/*****************************************************************************/
/*= Instrument specific defines =============================================*/
/*****************************************************************************/

/* --- Window -------------------------------------------------------------- */
#define RSESCI_SCREEN_A                     1
#define RSESCI_SCREEN_B                     2

/* --- Step Link ----------------------------------------------------------- */
#define RSESCI_FREQ_STEP_LINK_OFF           0
#define RSESCI_FREQ_STEP_LINK_RBW           1
#define RSESCI_FREQ_STEP_LINK_SPAN          2

/* --- Frequency Mode ------------------------------------------------------ */
#define RSESCI_FREQ_FIXED                   0
#define RSESCI_FREQ_SWEEP                   1

/* --- Axis Range Spacing -------------------------------------------------- */
#define RSESCI_SPACING_LIN                  0
#define RSESCI_SPACING_LOG                  1
#define RSESCI_SPACING_LDB                  2

/* --- Level Axis Unit ----------------------------------------------------- */
#define RSESCI_UNIT_DBM                     0
#define RSESCI_UNIT_VOLT                    1
#define RSESCI_UNIT_AMP                     2
#define RSESCI_UNIT_WATT                    3
#define RSESCI_UNIT_DBPW                    4
#define RSESCI_UNIT_DBUV                    5
#define RSESCI_UNIT_DBMV                    6
#define RSESCI_UNIT_DBUA                    7
#define RSESCI_UNIT_DBPT                    8
#define RSESCI_UNIT_DBUV_M                  9
#define RSESCI_UNIT_DBUA_M                  10
#define RSESCI_UNIT_DB                      11

/* --- Level Axis Scaling -------------------------------------------------- */
#define RSESCI_ABS                          0
#define RSESCI_REL                          1

/* --- RF Input Coupling --------------------------------------------------- */
#define RSESCI_COUPLING_AC                  0
#define RSESCI_COUPLING_DC                  1

/* --- RF Input Impedance -------------------------------------------------- */
#define RSESCI_INPUT_IMP_50                 0
#define RSESCI_INPUT_IMP_75                 1

/* --- Filter Type --------------------------------------------------------- */
#define RSESCI_FILTER_NORMAL                0
#define RSESCI_FILTER_FFT                   1
#define RSESCI_FILTER_CFIL                  2
#define RSESCI_FILTER_RRC                   3
#define RSESCI_FILTER_NOISE                 4
#define RSESCI_FILTER_PULSE                 5

/* --- Sweep Spacing ------------------------------------------------------- */
#define RSESCI_LIN                          0
#define RSESCI_LOG                          1
#define RSESCI_AUTO                         2

/* --- Trigger Source ------------------------------------------------------ */
#define RSESCI_TRIG_IMM                     0
#define RSESCI_TRIG_EXT                     1
#define RSESCI_TRIG_VID                     2
#define RSESCI_TRIG_IFP                     3
#define RSESCI_TRIG_RFP                     4
#define RSESCI_TRIG_TV                      5
#define RSESCI_TRIG_FM                      6
#define RSESCI_TRIG_AM                      7
#define RSESCI_TRIG_PM                      8
#define RSESCI_TRIG_AF                      9

/* --- Trigger Mode -------------------------------------------------------- */
#define RSESCI_TRIG_LEVEL                   0
#define RSESCI_TRIG_EDGE                    1

/* --- Trigger Polarity ---------------------------------------------------- */
#define RSESCI_POS                          0
#define RSESCI_NEG                          1

/* --- Field --------------------------------------------------------------- */
#define RSESCI_TVFIELD_ALL                  0
#define RSESCI_TVFIELD_ODD                  1
#define RSESCI_TVFIELD_EVEN                 2

/* --- CCVS Signal --------------------------------------------------------- */
#define RSESCI_INT                          0
#define RSESCI_EXT                          1

/* --- Trace Mode ---------------------------------------------------------- */
#define RSESCI_TRACE_WRITE                  0
#define RSESCI_TRACE_VIEW                   1
#define RSESCI_TRACE_AVG                    2
#define RSESCI_TRACE_MAXH                   3
#define RSESCI_TRACE_MINH                   4

/* --- Trace Detector ------------------------------------------------------ */
#define RSESCI_TRACEDET_APEAK               0
#define RSESCI_TRACEDET_NEG                 1
#define RSESCI_TRACEDET_POS                 2
#define RSESCI_TRACEDET_SAMPLE              3
#define RSESCI_TRACEDET_RMS                 4
#define RSESCI_TRACEDET_AVG                 5
#define RSESCI_TRACEDET_QPEAK               6
#define RSESCI_TRACEDET_CAVG                7
#define RSESCI_TRACEDET_CRMS                8

/* --- Expression ---------------------------------------------------------- */
#define RSESCI_MATH_TR1_SUB_TR2             0
#define RSESCI_MATH_TR1_SUB_TR3             1

/* --- Transmission Mode --------------------------------------------------- */
#define RSESCI_TRANS_NEVER                  0
#define RSESCI_TRANS_ALWAYS                 1

/* --- Polarity ------------------------------------------------------------ */
#define RSESCI_POL_POS                      0
#define RSESCI_POL_NEG                      1

/* --- Search Mode --------------------------------------------------------- */
#define RSESCI_MARKER_PMAX                  0
#define RSESCI_MARKER_NMAX                  1
#define RSESCI_MARKER_LMAX                  2
#define RSESCI_MARKER_RMAX                  3
#define RSESCI_MARKER_PMIN                  4
#define RSESCI_MARKER_NMIN                  5
#define RSESCI_MARKER_LMIN                  6
#define RSESCI_MARKER_RMIN                  7

/* --- Mkr Function -------------------------------------------------------- */
#define RSESCI_MARKER_TO_CENTER             0
#define RSESCI_MARKER_TO_STEP               1
#define RSESCI_MARKER_TO_REF                2

/* --- Power Measurement --------------------------------------------------- */
#define RSESCI_POWER_MEAS_AOFF              0
#define RSESCI_POWER_MEAS_PREV              1
#define RSESCI_POWER_MEAS_PEAK              2
#define RSESCI_POWER_MEAS_RMS               3
#define RSESCI_POWER_MEAS_MEAN              4
#define RSESCI_POWER_MEAS_SDEV              5

/* --- Result Type --------------------------------------------------------- */
#define RSESCI_RESULT_CURR                  0
#define RSESCI_RESULT_AVG                   1
#define RSESCI_RESULT_PHOLD                 2

/* --- Measurement --------------------------------------------------------- */
#define RSESCI_FDOMAIN_MEAS_OFF             0
#define RSESCI_FDOMAIN_MEAS_CPOW            1
#define RSESCI_FDOMAIN_MEAS_ACP             2
#define RSESCI_FDOMAIN_MEAS_MCAC            3
#define RSESCI_FDOMAIN_MEAS_OBW             4
#define RSESCI_FDOMAIN_MEAS_CN              5
#define RSESCI_FDOMAIN_MEAS_CN0             6

/* --- Standard ------------------------------------------------------------ */
#define RSESCI_STANDARD_NONE                0
#define RSESCI_STANDARD_NADC                1
#define RSESCI_STANDARD_TETRA               2
#define RSESCI_STANDARD_PDC                 3
#define RSESCI_STANDARD_PHS                 4
#define RSESCI_STANDARD_CDPD                5
#define RSESCI_STANDARD_FWCD                6
#define RSESCI_STANDARD_RWCD                7
#define RSESCI_STANDARD_F8CD                8
#define RSESCI_STANDARD_R8CD                9
#define RSESCI_STANDARD_F19C                10
#define RSESCI_STANDARD_R19C                11
#define RSESCI_STANDARD_FW3G                12
#define RSESCI_STANDARD_RW3G                13
#define RSESCI_STANDARD_D2CD                14
#define RSESCI_STANDARD_S2CD                15
#define RSESCI_STANDARD_M2CD                16
#define RSESCI_STANDARD_FIS95C0             17
#define RSESCI_STANDARD_RIS95C0             18
#define RSESCI_STANDARD_FIS95C1             19
#define RSESCI_STANDARD_RIS95C1             20
#define RSESCI_STANDARD_TCDM                21

/* --- Size ---------------------------------------------------------------- */
#define RSESCI_WINDOW_SMALL                 0
#define RSESCI_WINDOW_LARGE                 1

/* --- Channel Bandwidth --------------------------------------------------- */
#define RSESCI_BWID_TX                      0
#define RSESCI_BWID_ADJ                     1
#define RSESCI_BWID_ALT1                    2
#define RSESCI_BWID_ALT2                    3

/* --- ACP Reference Channel ----------------------------------------------- */
#define RSESCI_ACP_REFERENCE_TX1            0
#define RSESCI_ACP_REFERENCE_TX2            1
#define RSESCI_ACP_REFERENCE_TX3            2
#define RSESCI_ACP_REFERENCE_TX4            3
#define RSESCI_ACP_REFERENCE_MIN            4
#define RSESCI_ACP_REFERENCE_MAX            5
#define RSESCI_ACP_REFERENCE_LOW_HIGH       6

/* --- Measurement --------------------------------------------------------- */
#define RSESCI_STAT_AOFF                    0
#define RSESCI_STAT_APD                     1
#define RSESCI_STAT_CCDF                    2

/* --- Result Type --------------------------------------------------------- */
#define RSESCI_STAT_RESULT_ALL              0
#define RSESCI_STAT_RESULT_MEAN             1
#define RSESCI_STAT_RESULT_PEAK             2
#define RSESCI_STAT_RESULT_CFAC             3

/* --- Scan Mode ----------------------------------------------------------- */
#define RSESCI_SCAN_CONT                    1
#define RSESCI_SCAN_SING                    0

/* --- Final Detector ------------------------------------------------------ */
#define RSESCI_DETECTOR_MAXP                0
#define RSESCI_DETECTOR_MINP                1
#define RSESCI_DETECTOR_RMS                 2
#define RSESCI_DETECTOR_AVG                 3
#define RSESCI_DETECTOR_QPEAK               4
#define RSESCI_DETECTOR_CAV                 5

/* --- Search Method ------------------------------------------------------- */
#define RSESCI_SEARCH_SUBR                  0
#define RSESCI_SEARCH_PEAK                  1

/* --- Indication ---------------------------------------------------------- */
#define RSESCI_SYMBOL_OFF                   0
#define RSESCI_SYMBOL_CROSS                 1

/* --- Measurement --------------------------------------------------------- */
#define RSESCI_VNET_MEAS_FINAL              1
#define RSESCI_VNET_MEAS_PRESCAN            0

/* --- Protective Earth ---------------------------------------------------- */
#define RSESCI_EARTH_GROUNDED               0
#define RSESCI_EARTH_FLOATING               1

/* --- Phase --------------------------------------------------------------- */
#define RSESCI_PHASE_N                      0
#define RSESCI_PHASE_L1                     1
#define RSESCI_PHASE_L2                     2
#define RSESCI_PHASE_L3                     3

/* --- Demodulation -------------------------------------------------------- */
#define RSESCI_DEMOD_OFF                    0
#define RSESCI_DEMOD_AM                     1
#define RSESCI_DEMOD_FM                     2

/* --- Peak List Sort Mode ------------------------------------------------- */
#define RSESCI_X                            0
#define RSESCI_Y                            1

/* --- Calibration Source  ------------------------------------------------- */
#define RSESCI_RF_INPUT                     0
#define RSESCI_INT_CALIB_SOURCE             1

/* --- Clear --------------------------------------------------------------- */
#define RSESCI_CLEAR_ALL                    0
#define RSESCI_CLEAR_FILE                   1

/* --- File Operations ----------------------------------------------------- */
#define RSESCI_FILE_MAN_CDRIVE              0
#define RSESCI_FILE_MAN_CDIR                1
#define RSESCI_FILE_MAN_MDIR                2
#define RSESCI_FILE_MAN_RDIR                3
#define RSESCI_FILE_MAN_COPY                4
#define RSESCI_FILE_MAN_MOVE                5
#define RSESCI_FILE_MAN_DELETE              6
#define RSESCI_FILE_MAN_FORMAT              7

/* --- Instrument Mode ----------------------------------------------------- */
#define RSESCI_INSTRUMENT_MODE_SANALYZER    0
#define RSESCI_INSTRUMENT_MODE_RECEIVER     1
#define RSESCI_INSTRUMENT_MODE_ADEMOD       2

/* --- V-network Type ------------------------------------------------------ */
#define RSESCI_VNET_OFF                     0
#define RSESCI_VNET_TWO                     1
#define RSESCI_VNET_FOUR                    2

/* --- Interface Type ------------------------------------------------------ */
#define RSESCI_INTF_GPIB                    0
#define RSESCI_INTF_TTL                     1

/* --- Screen Mode --------------------------------------------------------- */
#define RSESCI_SCREEN_SINGLE                0
#define RSESCI_SCREEN_SPLIT                 1

/* --- Coupling Mode ------------------------------------------------------- */
#define RSESCI_INST_COUP_NONE               0
#define RSESCI_INST_COUP_RLEVEL             1
#define RSESCI_INST_COUP_CF_A               2
#define RSESCI_INST_COUP_CF_B               3

/* --- Sweep Mode ---------------------------------------------------------- */
#define RSESCI_SINGLE_SWEEP                 0
#define RSESCI_CONTINUOUS_SWEEP             1

/* --- Destination --------------------------------------------------------- */
#define RSESCI_HARDCOPY_DISK                0
#define RSESCI_HARDCOPY_PRINTER             1
#define RSESCI_HARDCOPY_CLIPBOARD           2

/* --- Data Format --------------------------------------------------------- */
#define RSESCI_HARDCOPY_WMF                 0
#define RSESCI_HARDCOPY_GDI                 1
#define RSESCI_HARDCOPY_EWMF                2
#define RSESCI_HARDCOPY_BMP                 3

/* --- Page Orientation ---------------------------------------------------- */
#define RSESCI_HARDCOPY_PORTRAIT            0
#define RSESCI_HARDCOPY_LANDSCAPE           1

/* --- Hardcopy Items ------------------------------------------------------ */
#define RSESCI_HARDCOPY_ALL                 0
#define RSESCI_HARDCOPY_TABLE               1
#define RSESCI_HARDCOPY_TRACE               2

/* --- Color Map ----------------------------------------------------------- */
#define RSESCI_CMAP_1                       1
#define RSESCI_CMAP_2                       2
#define RSESCI_CMAP_3                       3
#define RSESCI_CMAP_4                       4
#define RSESCI_CMAP_5                       5
#define RSESCI_CMAP_6                       6
#define RSESCI_CMAP_7                       7
#define RSESCI_CMAP_8                       8
#define RSESCI_CMAP_9                       9
#define RSESCI_CMAP_10                      10
#define RSESCI_CMAP_11                      11
#define RSESCI_CMAP_12                      12
#define RSESCI_CMAP_13                      13
#define RSESCI_CMAP_14                      14
#define RSESCI_CMAP_15                      15
#define RSESCI_CMAP_16                      16
#define RSESCI_CMAP_17                      17
#define RSESCI_CMAP_18                      18
#define RSESCI_CMAP_19                      19
#define RSESCI_CMAP_20                      20
#define RSESCI_CMAP_21                      21
#define RSESCI_CMAP_22                      22
#define RSESCI_CMAP_23                      23
#define RSESCI_CMAP_24                      24
#define RSESCI_CMAP_25                      25
#define RSESCI_CMAP_26                      26
#define RSESCI_CMAP_27                      27
#define RSESCI_CMAP_28                      28
#define RSESCI_CMAP_29                      29
#define RSESCI_CMAP_30                      30
#define RSESCI_CMAP_31                      31
#define RSESCI_CMAP_32                      32
#define RSESCI_CMAP_33                      33

/* --- Predefined Colors --------------------------------------------------- */
#define RSESCI_USER_DEFINED                -1
#define RSESCI_BLACK                        0
#define RSESCI_BLUE                         1
#define RSESCI_BROWN                        2
#define RSESCI_GREEN                        3
#define RSESCI_CYAN                         4
#define RSESCI_RED                          5
#define RSESCI_MAGNETA                      6
#define RSESCI_YELLOW                       7
#define RSESCI_WHITE                        8
#define RSESCI_DGRAY                        9
#define RSESCI_LGRAY                        10
#define RSESCI_LBLUE                        11
#define RSESCI_LGREEN                       12
#define RSESCI_LCYAN                        13
#define RSESCI_LRED                         14
#define RSESCI_LMAGNETA                     15

/* --- Predefined Colors --------------------------------------------------- */
#define RSESCI_DEFAULT_USER_DEFINED         0
#define RSESCI_DEFAULT_COLOR_SET            1
#define RSESCI_DEFAULT_SCREEN_COLORS        2

/* --- Default Colors ------------------------------------------------------ */
#define RSESCI_DEFAULT_1                    1
#define RSESCI_DEFAULT_2                    2

/* --- Result Display ------------------------------------------------------ */
#define RSESCI_FM_SUMMARY                   0
#define RSESCI_DEMOD_FM_SIG                 1
#define RSESCI_AFS_FM_SIG                   2
#define RSESCI_RFS_FM_SIG                   3
#define RSESCI_PM_SUMMARY                   4
#define RSESCI_DEMOD_PM_SIG                 5
#define RSESCI_AFS_PM_SIG                   6
#define RSESCI_AM_SUMMARY                   7
#define RSESCI_DEMOD_AM_SIG                 8
#define RSESCI_AFS_AM_SIG                   9
#define RSESCI_RFP_AM_SIG                   10

/* --- Display Size -------------------------------------------------------- */
#define RSESCI_SCREEN_SMALL                 0
#define RSESCI_SCREEN_LARGE                 1

/* --- Averaging Type ------------------------------------------------------ */
#define RSESCI_AVERAGE_LINEAR               0
#define RSESCI_AVERAGE_VIDEO                1

/* --- Angle Units --------------------------------------------------------- */
#define RSESCI_ANGLE_UNITS_RAD              0
#define RSESCI_ANGLE_UNITS_DEG              1

/* --- Modulation Measurement ---------------------------------------------- */
#define RSESCI_MOD_MEAS_PPEAK               0
#define RSESCI_MOD_MEAS_MPEAK               1
#define RSESCI_MOD_MEAS_MIDDLE              2
#define RSESCI_MOD_MEAS_RMS                 3

/* --- Demodulation Type --------------------------------------------------- */
#define RSESCI_DEMOD_TYPE_AM                0
#define RSESCI_DEMOD_TYPE_FM                1
#define RSESCI_DEMOD_TYPE_PM                2

/* --- Measurement Type ---------------------------------------------------- */
#define RSESCI_MEASUREMENT_IMM              0
#define RSESCI_MEASUREMENT_AVERAGE          1

/* --- Tracking Generator Measurement -------------------------------------- */
#define RSESCI_CORRECTION_TRAN              0
#define RSESCI_CORRECTION_REFL              1

/* --- Tracking Generator Calibration -------------------------------------- */
#define RSESCI_ACQ_THR                      0
#define RSESCI_ACQ_OPEN                     1

/* ---  Limit Line --------------------------------------------------------- */
#define RSESCI_LIMIT_LOWER                  0
#define RSESCI_LIMIT_UPPER                  1

/* --- Domain -------------------------------------------------------------- */
#define RSESCI_DOMAIN_FREQ                  0
#define RSESCI_DOMAIN_TIME                  1

/* --- Limit --------------------------------------------------------------- */
#define RSESCI_LIMIT_X                      2

/* --- Parity -------------------------------------------------------------- */
#define RSESCI_NONE                         0
#define RSESCI_EVEN                         1
#define RSESCI_ODD                          2

/* --- Port Type ----------------------------------------------------------- */
#define RSESCI_INPUT                        0
#define RSESCI_OUTPUT                       1

/* --- Data Set Items ------------------------------------------------------ */
#define RSESCI_DATA_SET_NONE                0
#define RSESCI_DATA_SET_DEFAULT             1
#define RSESCI_DATA_SET_ALL                 2
#define RSESCI_DATA_SET_CURRENT             3
#define RSESCI_DATA_SET_TRACES              4
#define RSESCI_DATA_SET_FINAL_LIST          5
#define RSESCI_DATA_SET_LIMIT_LINES         6
#define RSESCI_DATA_SET_CALIBRATION         7
#define RSESCI_DATA_SET_TRANSDUCERS         8

/* --- Decimal Point Notation ---------------------------------------------- */
#define RSESCI_DEC_SEPARATOR_POINT          0
#define RSESCI_DEC_SEPARATOR_COMMA          1

/* --- Mixed Instrument Mode ----------------------------------------------- */
#define RSESCI_MIXED_MODE_DISPLAY_SANALYZER 0
#define RSESCI_MIXED_MODE_DISPLAY_RECEIVER  1

/* --- Result Type --------------------------------------------------------- */
#define RSESCI_RESULT_TYPE_OFF              0
#define RSESCI_RESULT_TYPE_WRITE            1
#define RSESCI_RESULT_TYPE_AVERAGE          2
#define RSESCI_RESULT_TYPE_MAXHOLD          3
#define RSESCI_RESULT_TYPE_MINHOLD          4
#define RSESCI_RESULT_TYPE_VIEW             5

/* --- Compatibility Mode -------------------------------------------------- */
#define RSESCI_OFF                          0
#define RSESCI_FSP                          1

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC rsesci_init (ViRsrc resourceName, ViBoolean IDQuery,
                               ViBoolean resetDevice, ViPSession instrSession);
ViStatus _VI_FUNC rsesci_ReadSpectrum (ViSession instrSession,
                                       ViInt32 measurementMode,
                                       ViInt32 frequencyParameter,
                                       ViReal64 startFrequency,
                                       ViReal64 stopFrequency,
                                       ViPInt32 samplesReturned,
                                       ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsesci_SetCenterFrequency (ViSession instrSession,
                                             ViInt32 window,
                                             ViReal64 centerFrequency);
ViStatus _VI_FUNC rsesci_GetCenterFrequency (ViSession instrSession,
                                             ViInt32 window,
                                             ViPReal64 centerFrequency);
ViStatus _VI_FUNC rsesci_SetStartFrequency (ViSession instrSession,
                                            ViInt32 window,
                                            ViReal64 startFrequency);
ViStatus _VI_FUNC rsesci_GetStartFrequency (ViSession instrSession,
                                            ViInt32 window,
                                            ViPReal64 startFrequency);
ViStatus _VI_FUNC rsesci_SetStopFrequency (ViSession instrSession,
                                           ViInt32 window, ViReal64 stopFrequency);
ViStatus _VI_FUNC rsesci_GetStopFrequency (ViSession instrSession,
                                           ViInt32 window, ViPReal64 stopFrequency);
ViStatus _VI_FUNC rsesci_SetFrequencyOffset (ViSession instrSession,
                                             ViInt32 window,
                                             ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsesci_GetFrequencyOffset (ViSession instrSession,
                                             ViInt32 window,
                                             ViPReal64 frequencyOffset);
ViStatus _VI_FUNC rsesci_SetFrequencyMode (ViSession instrSession,
                                           ViInt32 window, ViInt32 frequencyMode);
ViStatus _VI_FUNC rsesci_GetFrequencyMode (ViSession instrSession,
                                           ViInt32 window, ViPInt32 frequencyMode);
ViStatus _VI_FUNC rsesci_SetCenterFrequencyStepWidth (ViSession instrSession,
                                                      ViInt32 window,
                                                      ViReal64 stepWidth);
ViStatus _VI_FUNC rsesci_GetCenterFrequencyStepWidth (ViSession instrSession,
                                                      ViInt32 window,
                                                      ViPReal64 stepWidth);
ViStatus _VI_FUNC rsesci_SetCenterFrequencyStepLink (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViInt32 stepLink);
ViStatus _VI_FUNC rsesci_GetCenterFrequencyStepLink (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViPInt32 stepLink);
ViStatus _VI_FUNC rsesci_SetCenterFrequencyStepLinkFactor
             (ViSession instrSession, ViInt32 window, ViInt32 stepLinkFactor);
ViStatus _VI_FUNC rsesci_GetCenterFrequencyStepLinkFactor
             (ViSession instrSession, ViInt32 window, ViPInt32 stepLinkFactor);
ViStatus _VI_FUNC rsesci_SetSignalTracking (ViSession instrSession,
                                            ViInt32 window,
                                            ViBoolean signalTracking);
ViStatus _VI_FUNC rsesci_GetSignalTracking (ViSession instrSession,
                                            ViInt32 window,
                                            ViPBoolean signalTracking);
ViStatus _VI_FUNC rsesci_SetSignalTrackingBandwidth (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViReal64 signalTrackingBandwidth);
ViStatus _VI_FUNC rsesci_GetSignalTrackingBandwidth (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViPReal64 signalTrackingBandwidth);
ViStatus _VI_FUNC rsesci_SetSignalTrackingThreshold (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViReal64 signalTrackingThreshold);
ViStatus _VI_FUNC rsesci_GetSignalTrackingThreshold (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViPReal64 signalTrackingThreshold);
ViStatus _VI_FUNC rsesci_SetSignalTrackingTrace (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViInt32 signalTrackingTrace);
ViStatus _VI_FUNC rsesci_GetSignalTrackingTrace (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViPInt32 signalTrackingTrace);
ViStatus _VI_FUNC rsesci_SetFrequencySpan (ViSession instrSession,
                                           ViInt32 window, ViReal64 frequencySpan);
ViStatus _VI_FUNC rsesci_GetFrequencySpan (ViSession instrSession,
                                           ViInt32 window, ViPReal64 frequencySpan);
ViStatus _VI_FUNC rsesci_SetReferenceLevel (ViSession instrSession,
                                            ViInt32 window,
                                            ViReal64 referenceLevel);
ViStatus _VI_FUNC rsesci_GetReferenceLevel (ViSession instrSession,
                                            ViInt32 window,
                                            ViPReal64 referenceLevel);
ViStatus _VI_FUNC rsesci_SetReferenceLevelOffset (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViReal64 referenceLevelOffset);
ViStatus _VI_FUNC rsesci_GetReferenceLevelOffset (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViPReal64 referenceLevelOffset);
ViStatus _VI_FUNC rsesci_SetReferenceLevelPosition (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViReal64 referenceLevelPosition);
ViStatus _VI_FUNC rsesci_GetReferenceLevelPosition (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViPReal64 referenceLevelPosition);
ViStatus _VI_FUNC rsesci_SetReferenceLevelPositionValue (ViSession instrSession,
                                                         ViInt32 window,
                                                         ViReal64 referenceLevelPosition);
ViStatus _VI_FUNC rsesci_GetReferenceLevelPositionValue (ViSession instrSession,
                                                         ViInt32 window,
                                                         ViPReal64 referenceLevelPosition);
ViStatus _VI_FUNC rsesci_SetLevelAxisRange (ViSession instrSession,
                                            ViInt32 window,
                                            ViReal64 levelAxisRange);
ViStatus _VI_FUNC rsesci_GetLevelAxisRange (ViSession instrSession,
                                            ViInt32 window,
                                            ViPReal64 levelAxisRange);
ViStatus _VI_FUNC rsesci_SetLevelAxisMinimum (ViSession instrSession,
                                              ViInt32 window,
                                              ViReal64 levelAxisMinimum);
ViStatus _VI_FUNC rsesci_GetLevelAxisMinimum (ViSession instrSession,
                                              ViInt32 window,
                                              ViPReal64 levelAxisMinimum);
ViStatus _VI_FUNC rsesci_SetLevelAxisRangeSpacing (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViInt32 levelAxisRangeSpacing);
ViStatus _VI_FUNC rsesci_GetLevelAxisRangeSpacing (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViPInt32 levelAxisRangeSpacing);
ViStatus _VI_FUNC rsesci_SetLevelAxisUnit (ViSession instrSession,
                                           ViInt32 window, ViInt32 levelAxisUnit);
ViStatus _VI_FUNC rsesci_GetLevelAxisUnit (ViSession instrSession,
                                           ViInt32 window, ViPInt32 levelAxisUnit);
ViStatus _VI_FUNC rsesci_SetLevelAxisScaling (ViSession instrSession,
                                              ViInt32 window,
                                              ViInt32 levelAxisScaling);
ViStatus _VI_FUNC rsesci_GetLevelAxisScaling (ViSession instrSession,
                                              ViInt32 window,
                                              ViPInt32 levelAxisScaling);
ViStatus _VI_FUNC rsesci_SetRFInputCoupling (ViSession instrSession,
                                             ViInt32 RFInputCoupling);
ViStatus _VI_FUNC rsesci_GetRFInputCoupling (ViSession instrSession,
                                             ViPInt32 RFInputCoupling);
ViStatus _VI_FUNC rsesci_SetRFInputAttenuation (ViSession instrSession,
                                                ViInt32 window,
                                                ViReal64 attenuation);
ViStatus _VI_FUNC rsesci_GetRFInputAttenuation (ViSession instrSession,
                                                ViInt32 window,
                                                ViPReal64 attenuation);
ViStatus _VI_FUNC rsesci_SetRFInputAttenuationAuto (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViBoolean attenuationAuto);
ViStatus _VI_FUNC rsesci_GetRFInputAttenuationAuto (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViPBoolean attenuationAuto);
ViStatus _VI_FUNC rsesci_SetRFInputAttenuationProtection (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViBoolean attenuationProtection);
ViStatus _VI_FUNC rsesci_GetRFInputAttenuationProtection (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViPBoolean attenuationProtection);
ViStatus _VI_FUNC rsesci_SetRFInputImpedance (ViSession instrSession,
                                              ViInt32 window,
                                              ViInt32 RFInputImpedance);
ViStatus _VI_FUNC rsesci_GetRFInputImpedance (ViSession instrSession,
                                              ViInt32 window,
                                              ViPInt32 RFInputImpedance);
ViStatus _VI_FUNC rsesci_SetPreamplifierAuto (ViSession instrSession,
                                              ViInt32 window,
                                              ViBoolean preamplifierAuto);
ViStatus _VI_FUNC rsesci_GetPreamplifierAuto (ViSession instrSession,
                                              ViInt32 window,
                                              ViPBoolean preamplifierAuto);
ViStatus _VI_FUNC rsesci_SetPreamplifier (ViSession instrSession,
                                          ViInt32 window, ViBoolean preamplifier);
ViStatus _VI_FUNC rsesci_GetPreamplifier (ViSession instrSession,
                                          ViInt32 window, ViPBoolean preamplifier);
ViStatus _VI_FUNC rsesci_SetResolutionBandwidth (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViReal64 resolutionBandwidth);
ViStatus _VI_FUNC rsesci_GetResolutionBandwidth (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViPReal64 resolutionBandwidth);
ViStatus _VI_FUNC rsesci_SetResolutionBandwidthAuto (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViBoolean autoResolutionBandwidth);
ViStatus _VI_FUNC rsesci_GetResolutionBandwidthAuto (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViPBoolean autoResolutionBandwidth);
ViStatus _VI_FUNC rsesci_SetResolutionBandwidthCouplingRatio
             (ViSession instrSession, ViInt32 window, ViReal64 ratio);
ViStatus _VI_FUNC rsesci_GetResolutionBandwidthCouplingRatio
             (ViSession instrSession, ViInt32 window, ViPReal64 ratio);
ViStatus _VI_FUNC rsesci_SetResolutionBandwidthFilterType
             (ViSession instrSession, ViInt32 window, ViInt32 filterType);
ViStatus _VI_FUNC rsesci_GetResolutionBandwidthFilterType
             (ViSession instrSession, ViInt32 window, ViPInt32 filterType);
ViStatus _VI_FUNC rsesci_SetVideoBandwidth (ViSession instrSession,
                                            ViInt32 window,
                                            ViReal64 videoBandwidth);
ViStatus _VI_FUNC rsesci_GetVideoBandwidth (ViSession instrSession,
                                            ViInt32 window,
                                            ViPReal64 videoBandwidth);
ViStatus _VI_FUNC rsesci_SetVideoBandwidthAuto (ViSession instrSession,
                                                ViInt32 window,
                                                ViBoolean autoVideoBandwidth);
ViStatus _VI_FUNC rsesci_GetVideoBandwidthAuto (ViSession instrSession,
                                                ViInt32 window,
                                                ViPBoolean autoVideoBandwidth);
ViStatus _VI_FUNC rsesci_SetVideoBandwidthCouplingRatio (ViSession instrSession,
                                                         ViInt32 window,
                                                         ViReal64 ratio);
ViStatus _VI_FUNC rsesci_GetVideoBandwidthCouplingRatio (ViSession instrSession,
                                                         ViInt32 window,
                                                         ViPReal64 ratio);
ViStatus _VI_FUNC rsesci_SetVideoBandwidthMode (ViSession instrSession,
                                                ViInt32 window,
                                                ViInt32 bandwidthMode);
ViStatus _VI_FUNC rsesci_GetVideoBandwidthMode (ViSession instrSession,
                                                ViInt32 window,
                                                ViPInt32 bandwidthMode);
ViStatus _VI_FUNC rsesci_ContinueSingleSweep (ViSession instrSession,
                                              ViInt32 window);
ViStatus _VI_FUNC rsesci_GetNumberStartedSweeps (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViPInt32 startedScans);
ViStatus _VI_FUNC rsesci_SetSweepMode (ViSession instrSession, ViInt32 window,
                                       ViInt32 continuousSweep);
ViStatus _VI_FUNC rsesci_GetSweepMode (ViSession instrSession, ViInt32 window,
                                       ViPInt32 continuousSweep);
ViStatus _VI_FUNC rsesci_SetSweepTime (ViSession instrSession, ViInt32 window,
                                       ViReal64 sweepTime);
ViStatus _VI_FUNC rsesci_GetSweepTime (ViSession instrSession, ViInt32 window,
                                       ViPReal64 sweepTime);
ViStatus _VI_FUNC rsesci_SetSweepTimeAuto (ViSession instrSession,
                                           ViInt32 window, ViBoolean autoSweepTime);
ViStatus _VI_FUNC rsesci_GetSweepTimeAuto (ViSession instrSession,
                                           ViInt32 window,
                                           ViPBoolean autoSweepTime);
ViStatus _VI_FUNC rsesci_SetSweepCount (ViSession instrSession, ViInt32 window,
                                        ViInt32 sweepCount);
ViStatus _VI_FUNC rsesci_GetSweepCount (ViSession instrSession, ViInt32 window,
                                        ViPInt32 sweepCount);
ViStatus _VI_FUNC rsesci_SetSweepPoints (ViSession instrSession, ViInt32 window,
                                         ViInt32 sweepPoints);
ViStatus _VI_FUNC rsesci_GetSweepPoints (ViSession instrSession, ViInt32 window,
                                         ViPInt32 sweepPoints);
ViStatus _VI_FUNC rsesci_SetSingleSweepDisplay (ViSession instrSession,
                                                ViBoolean displayState);
ViStatus _VI_FUNC rsesci_GetSingleSweepDisplay (ViSession instrSession,
                                                ViPBoolean displayState);
ViStatus _VI_FUNC rsesci_SetSweepSpacing (ViSession instrSession,
                                          ViInt32 window, ViInt32 sweepSpacing);
ViStatus _VI_FUNC rsesci_GetSweepSpacing (ViSession instrSession,
                                          ViInt32 window, ViPInt32 sweepSpacing);
ViStatus _VI_FUNC rsesci_Abort (ViSession instrSession);
ViStatus _VI_FUNC rsesci_Hold (ViSession instrSession);
ViStatus _VI_FUNC rsesci_SendTrigger (ViSession instrSession, ViInt32 window);
ViStatus _VI_FUNC rsesci_SendTriggerWaitOPC (ViSession instrSession,
                                             ViInt32 window, ViInt32 timeout);
ViStatus _VI_FUNC rsesci_SetTriggerSource (ViSession instrSession,
                                           ViInt32 window, ViInt32 triggerSource);
ViStatus _VI_FUNC rsesci_GetTriggerSource (ViSession instrSession,
                                           ViInt32 window, ViPInt32 triggerSource);
ViStatus _VI_FUNC rsesci_SetTriggerLevel (ViSession instrSession,
                                          ViInt32 window, ViInt32 signalType,
                                          ViReal64 triggerLevel);
ViStatus _VI_FUNC rsesci_GetTriggerLevel (ViSession instrSession,
                                          ViInt32 window, ViInt32 signalType,
                                          ViPReal64 triggerLevel);
ViStatus _VI_FUNC rsesci_SetTriggerOffset (ViSession instrSession,
                                           ViInt32 window, ViReal64 triggerDelay);
ViStatus _VI_FUNC rsesci_GetTriggerOffset (ViSession instrSession,
                                           ViInt32 window, ViPReal64 triggerDelay);
ViStatus _VI_FUNC rsesci_SetTriggerSourcePolarity (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViInt32 polarity);
ViStatus _VI_FUNC rsesci_GetTriggerSourcePolarity (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViPInt32 polarity);
ViStatus _VI_FUNC rsesci_SetGatedTrigger (ViSession instrSession,
                                          ViInt32 window, ViBoolean gatedTrigger);
ViStatus _VI_FUNC rsesci_GetGatedTrigger (ViSession instrSession,
                                          ViInt32 window, ViPBoolean gatedTrigger);
ViStatus _VI_FUNC rsesci_SetGatedTriggerSource (ViSession instrSession,
                                                ViInt32 window,
                                                ViInt32 triggerSource);
ViStatus _VI_FUNC rsesci_GetGatedTriggerSource (ViSession instrSession,
                                                ViInt32 window,
                                                ViPInt32 triggerSource);
ViStatus _VI_FUNC rsesci_SetGatedTriggerMode (ViSession instrSession,
                                              ViInt32 window, ViInt32 triggerMode);
ViStatus _VI_FUNC rsesci_GetGatedTriggerMode (ViSession instrSession,
                                              ViInt32 window, ViPInt32 triggerMode);
ViStatus _VI_FUNC rsesci_SetGatedTriggerPolarity (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViInt32 triggerPolarity);
ViStatus _VI_FUNC rsesci_GetGatedTriggerPolarity (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViPInt32 triggerPolarity);
ViStatus _VI_FUNC rsesci_SetGatedTriggerDelay (ViSession instrSession,
                                               ViInt32 window,
                                               ViReal64 triggerDelay);
ViStatus _VI_FUNC rsesci_GetGatedTriggerDelay (ViSession instrSession,
                                               ViInt32 window,
                                               ViPReal64 triggerDelay);
ViStatus _VI_FUNC rsesci_SetGatedTriggerLength (ViSession instrSession,
                                                ViInt32 window,
                                                ViReal64 triggerLength);
ViStatus _VI_FUNC rsesci_GetGatedTriggerLength (ViSession instrSession,
                                                ViInt32 window,
                                                ViPReal64 triggerLength);
ViStatus _VI_FUNC rsesci_SetTVTrigger (ViSession instrSession, ViInt32 window,
                                       ViBoolean TVTrigger);
ViStatus _VI_FUNC rsesci_GetTVTrigger (ViSession instrSession, ViInt32 window,
                                       ViPBoolean TVTrigger);
ViStatus _VI_FUNC rsesci_SetTVTriggerVerticalSync (ViSession instrSession,
                                                   ViInt32 window, ViInt32 field);
ViStatus _VI_FUNC rsesci_GetTVTriggerVerticalSync (ViSession instrSession,
                                                   ViInt32 window, ViPInt32 field);
ViStatus _VI_FUNC rsesci_SetTVTriggerHorizontalSync (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViInt32 lineNumber);
ViStatus _VI_FUNC rsesci_GetTVTriggerHorizontalSync (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViPInt32 lineNumber);
ViStatus _VI_FUNC rsesci_SetTVTriggerPolarity (ViSession instrSession,
                                               ViInt32 window, ViInt32 polarity);
ViStatus _VI_FUNC rsesci_GetTVTriggerPolarity (ViSession instrSession,
                                               ViInt32 window, ViPInt32 polarity);
ViStatus _VI_FUNC rsesci_SetTVTriggerLines (ViSession instrSession,
                                            ViInt32 window, ViInt32 linesSystem);
ViStatus _VI_FUNC rsesci_GetTVTriggerLines (ViSession instrSession,
                                            ViInt32 window, ViPInt32 linesSystem);
ViStatus _VI_FUNC rsesci_SetTVTriggerCCVS (ViSession instrSession,
                                           ViInt32 window, ViInt32 CCVSSignal);
ViStatus _VI_FUNC rsesci_GetTVTriggerCCVS (ViSession instrSession,
                                           ViInt32 window, ViPInt32 CCVSSignal);
ViStatus _VI_FUNC rsesci_SetTraceMode (ViSession instrSession, ViInt32 window,
                                       ViInt32 trace, ViInt32 traceMode);
ViStatus _VI_FUNC rsesci_GetTraceMode (ViSession instrSession, ViInt32 window,
                                       ViInt32 trace, ViPInt32 traceMode);
ViStatus _VI_FUNC rsesci_SetTraceBlanking (ViSession instrSession,
                                           ViInt32 window, ViInt32 trace,
                                           ViBoolean traceState);
ViStatus _VI_FUNC rsesci_GetTraceBlanking (ViSession instrSession,
                                           ViInt32 window, ViInt32 trace,
                                           ViPBoolean traceState);
ViStatus _VI_FUNC rsesci_SetTraceDetector (ViSession instrSession,
                                           ViInt32 window, ViInt32 trace,
                                           ViInt32 traceDetector);
ViStatus _VI_FUNC rsesci_GetTraceDetector (ViSession instrSession,
                                           ViInt32 window, ViInt32 trace,
                                           ViPInt32 traceDetector);
ViStatus _VI_FUNC rsesci_SetTraceDetectorAuto (ViSession instrSession,
                                               ViInt32 window, ViInt32 trace,
                                               ViBoolean coupleDetector);
ViStatus _VI_FUNC rsesci_GetTraceDetectorAuto (ViSession instrSession,
                                               ViInt32 window, ViInt32 trace,
                                               ViPBoolean coupleDetector);
ViStatus _VI_FUNC rsesci_SetTraceMath (ViSession instrSession, ViInt32 window,
                                       ViBoolean mathRelation);
ViStatus _VI_FUNC rsesci_GetTraceMath (ViSession instrSession, ViInt32 window,
                                       ViPBoolean mathRelation);
ViStatus _VI_FUNC rsesci_SetTraceMathMode (ViSession instrSession,
                                           ViInt32 mathMode);
ViStatus _VI_FUNC rsesci_GetTraceMathMode (ViSession instrSession,
                                           ViPInt32 mathMode);
ViStatus _VI_FUNC rsesci_SetTraceMathPosition (ViSession instrSession,
                                               ViInt32 window, ViReal64 position);
ViStatus _VI_FUNC rsesci_GetTraceMathPosition (ViSession instrSession,
                                               ViInt32 window, ViPReal64 position);
ViStatus _VI_FUNC rsesci_SetTraceMathExpression (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViInt32 expression);
ViStatus _VI_FUNC rsesci_GetTraceMathExpression (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViPInt32 expression);
ViStatus _VI_FUNC rsesci_SetTraceFeedControl (ViSession instrSession,
                                              ViInt32 control,
                                              ViInt32 transmissionMode);
ViStatus _VI_FUNC rsesci_GetTraceFeedControl (ViSession instrSession,
                                              ViInt32 control,
                                              ViPInt32 transmissionMode);
ViStatus _VI_FUNC rsesci_SetIQTrace (ViSession instrSession, ViInt32 window,
                                     ViBoolean IQTraceState);
ViStatus _VI_FUNC rsesci_GetIQTrace (ViSession instrSession, ViInt32 window,
                                     ViPBoolean IQTraceState);
ViStatus _VI_FUNC rsesci_SetIQTraceAveraging (ViSession instrSession,
                                              ViInt32 window,
                                              ViBoolean IQTraceState);
ViStatus _VI_FUNC rsesci_GetIQTraceAveraging (ViSession instrSession,
                                              ViInt32 window,
                                              ViPBoolean IQTraceState);
ViStatus _VI_FUNC rsesci_SetIQTraceAveragingCount (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViInt32 averageCount);
ViStatus _VI_FUNC rsesci_GetIQTraceAveragingCount (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViPInt32 averageCount);
ViStatus _VI_FUNC rsesci_SetIQTraceSynchronization (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViBoolean state);
ViStatus _VI_FUNC rsesci_GetIQTraceSynchronization (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViPBoolean state);
ViStatus _VI_FUNC rsesci_SetIQTraceSamplingRate (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViReal64 samplingRate);
ViStatus _VI_FUNC rsesci_GetIQTraceSamplingRate (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViPReal64 samplingRate);
ViStatus _VI_FUNC rsesci_SetIQTraceSettings (ViSession instrSession,
                                             ViInt32 window, ViReal64 samplingRate,
                                             ViInt32 triggerMode, ViInt32 polarity,
                                             ViReal64 bandwidth,
                                             ViInt32 pretriggerSamples,
                                             ViInt32 no_ofSamples);
ViStatus _VI_FUNC rsesci_GetIQTraceSettings (ViSession instrSession,
                                             ViInt32 window, ViPReal64 samplingRate,
                                             ViPInt32 triggerMode,
                                             ViPInt32 polarity, ViPReal64 bandwidth,
                                             ViPInt32 pretriggerSamples,
                                             ViPInt32 no_ofSamples);
ViStatus _VI_FUNC rsesci_CopyTrace (ViSession instrSession, ViInt32 window,
                                    ViInt32 sourceTrace, ViInt32 destinationTrace);
ViStatus _VI_FUNC rsesci_ReadTraceData (ViSession instrSession, ViInt32 window,
                                        ViInt32 trace, ViPInt32 no_ofPoints,
                                        ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsesci_WriteTraceData (ViSession instrSession, ViInt32 window,
                                         ViInt32 trace, ViInt32 no_ofPoints,
                                         ViReal64 _VI_FAR traceData[]);
ViStatus _VI_FUNC rsesci_ReadIQTraceData (ViSession instrSession,
                                          ViInt32 window, ViInt32 bufferSize,
                                          ViPInt32 no_ofPoints,
                                          ViReal64 _VI_FAR realParts_I[],
                                          ViReal64 _VI_FAR imaginaryParts_Q[]);
ViStatus _VI_FUNC rsesci_ReadIQTraceDataMemory (ViSession instrSession,
                                                ViInt32 window,
                                                ViInt32 offsetSamples,
                                                ViInt32 no_ofSamples,
                                                ViInt32 bufferSize,
                                                ViPInt32 no_ofPoints,
                                                ViReal64 _VI_FAR realParts_I[],
                                                ViReal64 _VI_FAR imaginaryParts_Q[]);
ViStatus _VI_FUNC rsesci_CalibrationTotal (ViSession instrSession,
                                           ViPInt32 result);
ViStatus _VI_FUNC rsesci_CalibrationAbort (ViSession instrSession);
ViStatus _VI_FUNC rsesci_CalibrationResults (ViSession instrSession,
                                             ViChar _VI_FAR calibrationResult[]);
ViStatus _VI_FUNC rsesci_SetCalibrationCorrection (ViSession instrSession,
                                                   ViBoolean calibrationState);
ViStatus _VI_FUNC rsesci_GetCalibrationCorrection (ViSession instrSession,
                                                   ViPBoolean calibrationState);
ViStatus _VI_FUNC rsesci_RunScan (ViSession instrSession);
ViStatus _VI_FUNC rsesci_HoldScan (ViSession instrSession);
ViStatus _VI_FUNC rsesci_ContinueScan (ViSession instrSession);
ViStatus _VI_FUNC rsesci_StopScan (ViSession instrSession);
ViStatus _VI_FUNC rsesci_SetScanMode (ViSession instrSession, ViInt32 scanMode);
ViStatus _VI_FUNC rsesci_GetScanMode (ViSession instrSession,
                                      ViPInt32 scanMode);
ViStatus _VI_FUNC rsesci_SetScanTimeDomain (ViSession instrSession,
                                            ViReal64 measurementTime);
ViStatus _VI_FUNC rsesci_GetScanTimeDomain (ViSession instrSession,
                                            ViPReal64 measurementTime);
ViStatus _VI_FUNC rsesci_SetScanDisplaySpacing (ViSession instrSession,
                                                ViInt32 window,
                                                ViInt32 displaySpacing);
ViStatus _VI_FUNC rsesci_GetScanDisplaySpacing (ViSession instrSession,
                                                ViInt32 window,
                                                ViPInt32 displaySpacing);
ViStatus _VI_FUNC rsesci_SetScanRanges (ViSession instrSession,
                                        ViInt32 number_of_ranges);
ViStatus _VI_FUNC rsesci_GetScanRanges (ViSession instrSession,
                                        ViPInt32 number_of_ranges);
ViStatus _VI_FUNC rsesci_SetScanStart (ViSession instrSession,
                                       ViInt32 scanRange, ViReal64 startFrequency);
ViStatus _VI_FUNC rsesci_GetScanStart (ViSession instrSession,
                                       ViInt32 scanRange, ViPReal64 startFrequency);
ViStatus _VI_FUNC rsesci_SetScanStop (ViSession instrSession, ViInt32 scanRange,
                                      ViReal64 stopFrequency);
ViStatus _VI_FUNC rsesci_GetScanStop (ViSession instrSession, ViInt32 scanRange,
                                      ViPReal64 stopFrequency);
ViStatus _VI_FUNC rsesci_SetScanStepSize (ViSession instrSession,
                                          ViInt32 scanRange, ViReal64 stepSize);
ViStatus _VI_FUNC rsesci_GetScanStepSize (ViSession instrSession,
                                          ViInt32 scanRange, ViPReal64 stepSize);
ViStatus _VI_FUNC rsesci_SetScanBandwidth (ViSession instrSession,
                                           ViInt32 scanRange, ViReal64 bandwidth);
ViStatus _VI_FUNC rsesci_GetScanBandwidth (ViSession instrSession,
                                           ViInt32 scanRange, ViPReal64 bandwidth);
ViStatus _VI_FUNC rsesci_SetScanMeasurementTime (ViSession instrSession,
                                                 ViInt32 scanRange,
                                                 ViReal64 measurementTime);
ViStatus _VI_FUNC rsesci_GetScanMeasurementTime (ViSession instrSession,
                                                 ViInt32 scanRange,
                                                 ViPReal64 measurementTime);
ViStatus _VI_FUNC rsesci_SetScanAutoRanging (ViSession instrSession,
                                             ViInt32 scanRange,
                                             ViBoolean autoRanging);
ViStatus _VI_FUNC rsesci_GetScanAutoRanging (ViSession instrSession,
                                             ViInt32 scanRange,
                                             ViPBoolean autoRanging);
ViStatus _VI_FUNC rsesci_SetScanRFAttenuation (ViSession instrSession,
                                               ViInt32 scanRange,
                                               ViReal64 attenuation);
ViStatus _VI_FUNC rsesci_GetScanRFAttenuation (ViSession instrSession,
                                               ViInt32 scanRange,
                                               ViPReal64 attenuation);
ViStatus _VI_FUNC rsesci_SetScanPreamplifier (ViSession instrSession,
                                              ViInt32 scanRange,
                                              ViBoolean preamplifierState);
ViStatus _VI_FUNC rsesci_GetScanPreamplifier (ViSession instrSession,
                                              ViInt32 scanRange,
                                              ViPBoolean preamplifierState);
ViStatus _VI_FUNC rsesci_SetScanAutoPreamplifier (ViSession instrSession,
                                                  ViInt32 scanRange,
                                                  ViBoolean preamplifierInAutoranging);
ViStatus _VI_FUNC rsesci_GetScanAutoPreamplifier (ViSession instrSession,
                                                  ViInt32 scanRange,
                                                  ViPBoolean preamplifierInAutoranging);
ViStatus _VI_FUNC rsesci_SetMarker (ViSession instrSession, ViInt32 window,
                                    ViInt32 marker, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetMarker (ViSession instrSession, ViInt32 window,
                                    ViInt32 marker, ViPBoolean state);
ViStatus _VI_FUNC rsesci_AllMarkersOff (ViSession instrSession, ViInt32 window);
ViStatus _VI_FUNC rsesci_SetMarkerPosition (ViSession instrSession,
                                            ViInt32 window, ViInt32 marker,
                                            ViReal64 x);
ViStatus _VI_FUNC rsesci_GetMarkerPosition (ViSession instrSession,
                                            ViInt32 window, ViInt32 marker,
                                            ViPReal64 x);
ViStatus _VI_FUNC rsesci_GetMarkerValue (ViSession instrSession, ViInt32 window,
                                         ViInt32 marker, ViPReal64 y);
ViStatus _VI_FUNC rsesci_SetMarkerZoom (ViSession instrSession, ViInt32 window,
                                        ViReal64 zoom);
ViStatus _VI_FUNC rsesci_GetMarkerZoom (ViSession instrSession, ViInt32 window,
                                        ViPReal64 zoom);
ViStatus _VI_FUNC rsesci_SetMarkerFrequencyCounter (ViSession instrSession,
                                                    ViInt32 window, ViInt32 marker,
                                                    ViBoolean counterState);
ViStatus _VI_FUNC rsesci_GetMarkerFrequencyCounter (ViSession instrSession,
                                                    ViInt32 window, ViInt32 marker,
                                                    ViPBoolean counterState);
ViStatus _VI_FUNC rsesci_SetMarkerFrequencyCounterResolution
             (ViSession instrSession, ViInt32 window, ViReal64 resolution);
ViStatus _VI_FUNC rsesci_GetMarkerFrequencyCounterResolution
             (ViSession instrSession, ViInt32 window, ViPReal64 resolution);
ViStatus _VI_FUNC rsesci_GetMarkerFrequencyCounterValue (ViSession instrSession,
                                                         ViInt32 window,
                                                         ViInt32 marker,
                                                         ViPReal64 frequencyCounterValue);
ViStatus _VI_FUNC rsesci_SetDeltaMarker (ViSession instrSession, ViInt32 window,
                                         ViInt32 marker, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetDeltaMarker (ViSession instrSession, ViInt32 window,
                                         ViInt32 marker, ViPBoolean state);
ViStatus _VI_FUNC rsesci_AllDeltaMarkersOff (ViSession instrSession,
                                             ViInt32 window);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerMode (ViSession instrSession,
                                             ViInt32 deltaMarkerMode);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerMode (ViSession instrSession,
                                             ViPInt32 deltaMarkerMode);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerPosition (ViSession instrSession,
                                                 ViInt32 window, ViInt32 marker,
                                                 ViReal64 position);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerPosition (ViSession instrSession,
                                                 ViInt32 window, ViInt32 marker,
                                                 ViPReal64 position);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerRelativePosition (ViSession instrSession,
                                                         ViInt32 window,
                                                         ViInt32 marker,
                                                         ViPReal64 position);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerValue (ViSession instrSession,
                                              ViInt32 window, ViInt32 marker,
                                              ViPReal64 y);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerReferenceFixed (ViSession instrSession,
                                                       ViInt32 window,
                                                       ViBoolean fixedReferenceValue);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerReferenceFixed (ViSession instrSession,
                                                       ViInt32 window,
                                                       ViPBoolean fixedReferenceValue);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerReferencePointLevel
             (ViSession instrSession, ViInt32 window,
              ViReal64 referencePointLevel);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerReferencePointLevel
             (ViSession instrSession, ViInt32 window,
              ViPReal64 referencePointLevel);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerReferencePointToPeak
             (ViSession instrSession, ViInt32 window);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerReferencePointLevelOffset
             (ViSession instrSession, ViInt32 window, ViReal64 offset);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerReferencePointLevelOffset
             (ViSession instrSession, ViInt32 window, ViPReal64 offset);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerReferencePointPosition
             (ViSession instrSession, ViInt32 window, ViReal64 referencePoint);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerReferencePointPosition
             (ViSession instrSession, ViInt32 window, ViPReal64 referencePoint);
ViStatus _VI_FUNC rsesci_MarkerSearch (ViSession instrSession, ViInt32 window,
                                       ViInt32 marker, ViInt32 searchMode);
ViStatus _VI_FUNC rsesci_SetMarkerTo (ViSession instrSession, ViInt32 window,
                                      ViInt32 marker, ViInt32 mkrFunction);
ViStatus _VI_FUNC rsesci_SetMarkerToTrace (ViSession instrSession,
                                           ViInt32 window, ViInt32 marker,
                                           ViInt32 trace);
ViStatus _VI_FUNC rsesci_GetMarkerToTrace (ViSession instrSession,
                                           ViInt32 window, ViInt32 marker,
                                           ViPInt32 trace);
ViStatus _VI_FUNC rsesci_SetPeakExcursion (ViSession instrSession,
                                           ViInt32 window, ViReal64 peakExcursion);
ViStatus _VI_FUNC rsesci_GetPeakExcursion (ViSession instrSession,
                                           ViInt32 window, ViPReal64 peakExcursion);
ViStatus _VI_FUNC rsesci_SetLocalOscillatorSuppression (ViSession instrSession,
                                                        ViBoolean localOscillatorSuppression);
ViStatus _VI_FUNC rsesci_GetLocalOscillatorSuppression (ViSession instrSession,
                                                        ViPBoolean localOscillatorSuppression);
ViStatus _VI_FUNC rsesci_SetMarkerSettingsCoupled (ViSession instrSession,
                                                   ViInt32 window, ViInt32 marker,
                                                   ViBoolean couplingState);
ViStatus _VI_FUNC rsesci_GetMarkerSettingsCoupled (ViSession instrSession,
                                                   ViInt32 window, ViInt32 marker,
                                                   ViPBoolean couplingState);
ViStatus _VI_FUNC rsesci_DeltaMarkerSearch (ViSession instrSession,
                                            ViInt32 window, ViInt32 marker,
                                            ViInt32 searchMode);
ViStatus _VI_FUNC rsesci_SetDeltaMarkerToTrace (ViSession instrSession,
                                                ViInt32 window, ViInt32 marker,
                                                ViInt32 trace);
ViStatus _VI_FUNC rsesci_GetDeltaMarkerToTrace (ViSession instrSession,
                                                ViInt32 window, ViInt32 marker,
                                                ViPInt32 trace);
ViStatus _VI_FUNC rsesci_SetSearchLimitLines (ViSession instrSession,
                                              ViInt32 window,
                                              ViBoolean limitedRange);
ViStatus _VI_FUNC rsesci_GetSearchLimitLines (ViSession instrSession,
                                              ViInt32 window,
                                              ViPBoolean limitedRange);
ViStatus _VI_FUNC rsesci_SetSearchLeftLimitLine (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViReal64 leftLimit);
ViStatus _VI_FUNC rsesci_GetSearchLeftLimitLine (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViPReal64 leftLimit);
ViStatus _VI_FUNC rsesci_SetSearchRightLimitLine (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViReal64 rightLimit);
ViStatus _VI_FUNC rsesci_GetSearchRightLimitLine (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViPReal64 rightLimit);
ViStatus _VI_FUNC rsesci_SetSearchThreshold (ViSession instrSession,
                                             ViInt32 window,
                                             ViBoolean searchThreshold);
ViStatus _VI_FUNC rsesci_GetSearchThreshold (ViSession instrSession,
                                             ViInt32 window,
                                             ViPBoolean searchThreshold);
ViStatus _VI_FUNC rsesci_SetSearchThresholdLine (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViReal64 threshold);
ViStatus _VI_FUNC rsesci_GetSearchThresholdLine (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViPReal64 threshold);
ViStatus _VI_FUNC rsesci_SetNoiseDensityMeasurement (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViBoolean noiseMeasurement);
ViStatus _VI_FUNC rsesci_GetNoiseDensityMeasurement (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViPBoolean noiseMeasurement);
ViStatus _VI_FUNC rsesci_GetNoiseDensityMeasurementValue (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViPReal64 noiseMeasurement);
ViStatus _VI_FUNC rsesci_SetPhaseNoiseMeasurement (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViBoolean phaseNoiseMeasurement);
ViStatus _VI_FUNC rsesci_GetPhaseNoiseMeasurement (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViPBoolean phaseNoiseMeasurement);
ViStatus _VI_FUNC rsesci_GetPhaseNoiseMeasurementValue (ViSession instrSession,
                                                        ViInt32 window,
                                                        ViPReal64 phaseNoiseMeasurement);
ViStatus _VI_FUNC rsesci_SetNdBDown (ViSession instrSession, ViInt32 window,
                                     ViBoolean n_dBDownState);
ViStatus _VI_FUNC rsesci_GetNdBDown (ViSession instrSession, ViInt32 window,
                                     ViPBoolean n_dBDownState);
ViStatus _VI_FUNC rsesci_SetNdBDownLevelSpacing (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViReal64 levelSpacing);
ViStatus _VI_FUNC rsesci_GetNdBDownLevelSpacing (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViPReal64 levelSpacing);
ViStatus _VI_FUNC rsesci_GetNdBDownBandwidth (ViSession instrSession,
                                              ViInt32 window,
                                              ViPReal64 frequencySpacing);
ViStatus _VI_FUNC rsesci_GetNdBDownFrequencies (ViSession instrSession,
                                                ViInt32 window,
                                                ViReal64 _VI_FAR frequencies[]);
ViStatus _VI_FUNC rsesci_GetNdBDownTimes (ViSession instrSession,
                                          ViInt32 window, ViReal64 _VI_FAR times[]);
ViStatus _VI_FUNC rsesci_SearchForPeakList (ViSession instrSession,
                                            ViInt32 window,
                                            ViInt32 number_of_maxima);
ViStatus _VI_FUNC rsesci_SetPeakListSortMode (ViSession instrSession,
                                              ViInt32 window, ViInt32 sortMode);
ViStatus _VI_FUNC rsesci_GetPeakListSortMode (ViSession instrSession,
                                              ViInt32 window, ViPInt32 sortMode);
ViStatus _VI_FUNC rsesci_GetPeakListCount (ViSession instrSession,
                                           ViInt32 window, ViPInt32 peakCount);
ViStatus _VI_FUNC rsesci_GetPeakListXValues (ViSession instrSession,
                                             ViInt32 window,
                                             ViReal64 _VI_FAR xValues[]);
ViStatus _VI_FUNC rsesci_GetPeakListYValues (ViSession instrSession,
                                             ViInt32 window,
                                             ViReal64 _VI_FAR yValues[]);
ViStatus _VI_FUNC rsesci_SetMarkerDemodulation (ViSession instrSession,
                                                ViInt32 window, ViInt32 marker,
                                                ViBoolean demodulationState);
ViStatus _VI_FUNC rsesci_GetMarkerDemodulation (ViSession instrSession,
                                                ViInt32 window, ViInt32 marker,
                                                ViPBoolean demodulationState);
ViStatus _VI_FUNC rsesci_SetMarkerDemodulationType (ViSession instrSession,
                                                    ViInt32 demodulationType);
ViStatus _VI_FUNC rsesci_GetMarkerDemodulationType (ViSession instrSession,
                                                    ViPInt32 demodulationType);
ViStatus _VI_FUNC rsesci_SetMarkerStopTime (ViSession instrSession,
                                            ViReal64 holdoff);
ViStatus _VI_FUNC rsesci_GetMarkerStopTime (ViSession instrSession,
                                            ViPReal64 holdoff);
ViStatus _VI_FUNC rsesci_SetContinuousMarkerDemodulation (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViBoolean continuousDemodulation);
ViStatus _VI_FUNC rsesci_GetContinuousMarkerDemodulation (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViPBoolean continuousDemodulation);
ViStatus _VI_FUNC rsesci_SetTimeDomainPower (ViSession instrSession,
                                             ViInt32 window,
                                             ViInt32 powerMeasurement,
                                             ViBoolean measurementState);
ViStatus _VI_FUNC rsesci_GetTimeDomainPower (ViSession instrSession,
                                             ViInt32 window,
                                             ViInt32 powerMeasurement,
                                             ViPBoolean measurementState);
ViStatus _VI_FUNC rsesci_SetTimeDomainPowerAveraging (ViSession instrSession,
                                                      ViInt32 window,
                                                      ViBoolean averaging);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerAveraging (ViSession instrSession,
                                                      ViInt32 window,
                                                      ViPBoolean averaging);
ViStatus _VI_FUNC rsesci_SetTimeDomainPowerPeakHold (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViBoolean peakHold);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerPeakHold (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViPBoolean peakHold);
ViStatus _VI_FUNC rsesci_SetTimeDomainPowerMode (ViSession instrSession,
                                                 ViInt32 window, ViInt32 mode);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerMode (ViSession instrSession,
                                                 ViInt32 window, ViPInt32 mode);
ViStatus _VI_FUNC rsesci_SetTimeDomainPowerReference (ViSession instrSession,
                                                      ViInt32 window);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerMeanValue (ViSession instrSession,
                                                      ViInt32 window,
                                                      ViInt32 resultType,
                                                      ViPReal64 result);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerPeakValue (ViSession instrSession,
                                                      ViInt32 window,
                                                      ViInt32 resultType,
                                                      ViPReal64 result);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerRMSValue (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViInt32 resultType,
                                                     ViPReal64 result);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerStandardDeviationValue
             (ViSession instrSession, ViInt32 window, ViInt32 resultType,
              ViPReal64 result);
ViStatus _VI_FUNC rsesci_GetTimeDomainPowerSignalPulsesValue
             (ViSession instrSession, ViInt32 window,
              ViReal64 time_offset_of_first_pulse, ViReal64 measurementTime,
              ViReal64 period, ViInt32 pulses, ViPReal64 result);
ViStatus _VI_FUNC rsesci_SetPowerMeasurement (ViSession instrSession,
                                              ViInt32 window, ViInt32 measurement);
ViStatus _VI_FUNC rsesci_GetPowerMeasurement (ViSession instrSession,
                                              ViInt32 window, ViPInt32 measurement);
ViStatus _VI_FUNC rsesci_AdjustPowerMeasurementSetting (ViSession instrSession,
                                                        ViInt32 window,
                                                        ViInt32 measurement);
ViStatus _VI_FUNC rsesci_AdjustReferenceLevel (ViSession instrSession,
                                               ViInt32 window);
ViStatus _VI_FUNC rsesci_GetPowerMeasurementValue (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViInt32 measurement,
                                                   ViInt32 arraySize,
                                                   ViReal64 _VI_FAR result[]);
ViStatus _VI_FUNC rsesci_SetChannelPowerHzMeasurement (ViSession instrSession,
                                                       ViInt32 window,
                                                       ViBoolean relativeResult);
ViStatus _VI_FUNC rsesci_GetChannelPowerHzMeasurement (ViSession instrSession,
                                                       ViInt32 window,
                                                       ViPBoolean relativeResult);
ViStatus _VI_FUNC rsesci_SetCPACPStandard (ViSession instrSession,
                                           ViInt32 window, ViInt32 standard);
ViStatus _VI_FUNC rsesci_GetCPACPStandard (ViSession instrSession,
                                           ViInt32 window, ViPInt32 standard);
ViStatus _VI_FUNC rsesci_SetCPReference (ViSession instrSession,
                                         ViInt32 window);
ViStatus _VI_FUNC rsesci_SetNoiseCorrection (ViSession instrSession,
                                             ViInt32 window, ViBoolean correction);
ViStatus _VI_FUNC rsesci_GetNoiseCorrection (ViSession instrSession,
                                             ViInt32 window, ViPBoolean correction);
ViStatus _VI_FUNC rsesci_SetFastACP (ViSession instrSession, ViInt32 window,
                                     ViBoolean fastACP);
ViStatus _VI_FUNC rsesci_GetFastACP (ViSession instrSession, ViInt32 window,
                                     ViPBoolean fastACP);
ViStatus _VI_FUNC rsesci_SetFullSizeDiagram (ViSession instrSession,
                                             ViInt32 size);
ViStatus _VI_FUNC rsesci_GetFullSizeDiagram (ViSession instrSession,
                                             ViPInt32 size);
ViStatus _VI_FUNC rsesci_SetNumberAdjacentChannels (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViInt32 number_ofAdjacentChannels);
ViStatus _VI_FUNC rsesci_GetNumberAdjacentChannels (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViPInt32 number_ofAdjacentChannels);
ViStatus _VI_FUNC rsesci_SetNumberTXChannels (ViSession instrSession,
                                              ViInt32 window,
                                              ViInt32 number_ofCarriers);
ViStatus _VI_FUNC rsesci_GetNumberTXChannels (ViSession instrSession,
                                              ViInt32 window,
                                              ViPInt32 number_ofCarriers);
ViStatus _VI_FUNC rsesci_SetTXACPChannelBandwidth (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViInt32 channelBandwidth,
                                                   ViReal64 channelBandwidthValue);
ViStatus _VI_FUNC rsesci_GetTXACPChannelBandwidth (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViInt32 channelBandwidth,
                                                   ViPReal64 channelBandwidthValue);
ViStatus _VI_FUNC rsesci_SetACPChannelSpacing (ViSession instrSession,
                                               ViInt32 window,
                                               ViInt32 channelSpacing,
                                               ViReal64 channelSpacingValue);
ViStatus _VI_FUNC rsesci_GetACPChannelSpacing (ViSession instrSession,
                                               ViInt32 window,
                                               ViInt32 channelSpacing,
                                               ViPReal64 channelSpacingValue);
ViStatus _VI_FUNC rsesci_SetACPReferenceChannel (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViInt32 ACPReferenceChannel);
ViStatus _VI_FUNC rsesci_SetCPACPPowerMeasurementMode (ViSession instrSession,
                                                       ViInt32 window,
                                                       ViInt32 mode);
ViStatus _VI_FUNC rsesci_GetCPACPPowerMeasurementMode (ViSession instrSession,
                                                       ViInt32 window,
                                                       ViPInt32 mode);
ViStatus _VI_FUNC rsesci_SetCPACPMeasurementTrace (ViSession instrSession,
                                                   ViInt32 window, ViInt32 trace);
ViStatus _VI_FUNC rsesci_GetCPACPMeasurementTrace (ViSession instrSession,
                                                   ViInt32 window, ViPInt32 trace);
ViStatus _VI_FUNC rsesci_SetACPLimitChecking (ViSession instrSession,
                                              ViInt32 window,
                                              ViBoolean limitChecking);
ViStatus _VI_FUNC rsesci_GetACPLimitChecking (ViSession instrSession,
                                              ViInt32 window,
                                              ViPBoolean limitChecking);
ViStatus _VI_FUNC rsesci_SetACPLimits (ViSession instrSession, ViInt32 window,
                                       ViInt32 limitType, ViInt32 mode,
                                       ViBoolean state, ViReal64 limitValue);
ViStatus _VI_FUNC rsesci_GetACPLimits (ViSession instrSession, ViInt32 window,
                                       ViInt32 mode, ViInt32 limitType,
                                       ViPBoolean state, ViPReal64 limitValue);
ViStatus _VI_FUNC rsesci_GetACPLimitCheckingResult (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViInt32 limitType,
                                                    ViPBoolean result);
ViStatus _VI_FUNC rsesci_SetPowerBandwidthPercentage (ViSession instrSession,
                                                      ViInt32 window,
                                                      ViReal64 percentage);
ViStatus _VI_FUNC rsesci_GetPowerBandwidthPercentage (ViSession instrSession,
                                                      ViInt32 window,
                                                      ViPReal64 percentage);
ViStatus _VI_FUNC rsesci_SetChannelBandwidth (ViSession instrSession,
                                              ViInt32 window,
                                              ViReal64 channelBandwidth);
ViStatus _VI_FUNC rsesci_GetChannelBandwidth (ViSession instrSession,
                                              ViInt32 window,
                                              ViPReal64 channelBandwidth);
ViStatus _VI_FUNC rsesci_SetSignalAmplitudeStatistics (ViSession instrSession,
                                                       ViInt32 measurement);
ViStatus _VI_FUNC rsesci_GetSignalAmplitudeStatistics (ViSession instrSession,
                                                       ViPInt32 measurement);
ViStatus _VI_FUNC rsesci_SetCCDFPercentMarker (ViSession instrSession,
                                               ViInt32 window, ViInt32 marker,
                                               ViReal64 position);
ViStatus _VI_FUNC rsesci_GetCCDFPercentMarker (ViSession instrSession,
                                               ViInt32 window, ViInt32 marker,
                                               ViPReal64 position);
ViStatus _VI_FUNC rsesci_SetStatisticsNumberSamples (ViSession instrSession,
                                                     ViReal64 numberOfSamples);
ViStatus _VI_FUNC rsesci_GetStatisticsNumberSamples (ViSession instrSession,
                                                     ViPReal64 numberOfSamples);
ViStatus _VI_FUNC rsesci_StatisticsAdjustSettings (ViSession instrSession);
ViStatus _VI_FUNC rsesci_StatisticsDefaultSettings (ViSession instrSession);
ViStatus _VI_FUNC rsesci_GetStatisticalMeasurementsResults
             (ViSession instrSession, ViInt32 trace, ViInt32 resultType,
              ViReal64 _VI_FAR result[]);
ViStatus _VI_FUNC rsesci_SetStatisticsXAxisReferenceLevel
             (ViSession instrSession, ViReal64 referenceLevel);
ViStatus _VI_FUNC rsesci_GetStatisticsXAxisReferenceLevel
             (ViSession instrSession, ViPReal64 referenceLevel);
ViStatus _VI_FUNC rsesci_SetStatisticsXAxisRange (ViSession instrSession,
                                                  ViReal64 range);
ViStatus _VI_FUNC rsesci_GetStatisticsXAxisRange (ViSession instrSession,
                                                  ViPReal64 range);
ViStatus _VI_FUNC rsesci_SetStatisticsYAxisMinValue (ViSession instrSession,
                                                     ViReal64 minValue);
ViStatus _VI_FUNC rsesci_GetStatisticsYAxisMinValue (ViSession instrSession,
                                                     ViPReal64 minValue);
ViStatus _VI_FUNC rsesci_SetStatisticsYAxisMaxValue (ViSession instrSession,
                                                     ViReal64 maxValue);
ViStatus _VI_FUNC rsesci_GetStatisticsYAxisMaxValue (ViSession instrSession,
                                                     ViPReal64 maxValue);
ViStatus _VI_FUNC rsesci_SetModulationDepthMeasurement (ViSession instrSession,
                                                        ViInt32 window,
                                                        ViBoolean modulationDepthMeasurement);
ViStatus _VI_FUNC rsesci_GetModulationDepthMeasurement (ViSession instrSession,
                                                        ViInt32 window,
                                                        ViPBoolean modulationDepthMeasurement);
ViStatus _VI_FUNC rsesci_GetModulationDepthMeasurementValue
             (ViSession instrSession, ViInt32 window, ViPReal64 result);
ViStatus _VI_FUNC rsesci_SetThirdOrderInterceptMeasurement
             (ViSession instrSession, ViInt32 window, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetThirdOrderInterceptMeasurement
             (ViSession instrSession, ViInt32 window, ViPBoolean state);
ViStatus _VI_FUNC rsesci_GetThirdOrderInterceptMeasurementValue
             (ViSession instrSession, ViInt32 window, ViPReal64 TOIResult);
ViStatus _VI_FUNC rsesci_SetMultiplePowerMeasurementParameters
             (ViSession instrSession, ViInt32 window, ViBoolean peakDetector,
              ViBoolean RMSDetector, ViBoolean averageDetector, ViInt32 triggerMode,
              ViInt32 triggerSlope, ViReal64 triggerOffset, ViReal64 gateLength);
ViStatus _VI_FUNC rsesci_GetMultiplePowerMeasurementParameters
             (ViSession instrSession, ViInt32 window, ViPBoolean peakDetector,
              ViPBoolean RMSDetector, ViPBoolean averageDetector,
              ViPInt32 triggerMode, ViPInt32 triggerSlope, ViPReal64 triggerOffset,
              ViPReal64 gateLength);
ViStatus _VI_FUNC rsesci_MultiplePowerMeasurementSequence
             (ViSession instrSession, ViInt32 window, ViInt32 number_ofEntries,
              ViReal64 _VI_FAR analyzerFrequency[],
              ViReal64 _VI_FAR referenceLevel[],
              ViReal64 _VI_FAR RFInputAttenuation[], ViInt32 _VI_FAR filterType[],
              ViReal64 _VI_FAR resolutionBandwidth[],
              ViReal64 _VI_FAR videoBandwidth[], ViReal64 _VI_FAR measurementTime[],
              ViReal64 _VI_FAR triggerLevel[]);
ViStatus _VI_FUNC rsesci_MultiplePowerMeasurementResults (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViPInt32 number_ofResults,
                                                          ViReal64 _VI_FAR powerMeasurementResults[]);
ViStatus _VI_FUNC rsesci_DeactivateMultiplePowerMeasurement
             (ViSession instrSession, ViInt32 window);
ViStatus _VI_FUNC rsesci_MultipleBurstPowerMeasurementSequence
             (ViSession instrSession, ViInt32 window,
              ViReal64 analyzerFrequency, ViReal64 resolutionBandwidth,
              ViReal64 measurementTime, ViInt32 triggerSource,
              ViReal64 triggerLevel, ViReal64 triggerOffset,
              ViInt32 measurementType, ViInt32 no_ofMeasurements);
ViStatus _VI_FUNC rsesci_MultipleBurstPowerMeasurementResult
             (ViSession instrSession, ViInt32 window,
              ViReal64 _VI_FAR powerMeasurementResults[],
              ViPInt32 number_ofResults);
ViStatus _VI_FUNC rsesci_MultipleBurstPowerMeasurementResultMinimum
             (ViSession instrSession, ViInt32 window,
              ViPReal64 powerMeasurementResult);
ViStatus _VI_FUNC rsesci_SetReceiverDetector (ViSession instrSession,
                                              ViInt32 window, ViBoolean maxPeak,
                                              ViBoolean minPeak, ViBoolean RMS,
                                              ViBoolean average,
                                              ViBoolean quasipeak,
                                              ViBoolean CISPRAverage);
ViStatus _VI_FUNC rsesci_GetReceiverDetector (ViSession instrSession,
                                              ViInt32 window, ViPBoolean maxPeak,
                                              ViPBoolean minPeak, ViPBoolean RMS,
                                              ViPBoolean average,
                                              ViPBoolean quasipeak,
                                              ViPBoolean CISPRAverage);
ViStatus _VI_FUNC rsesci_SetFinalReceiverDetector (ViSession instrSession,
                                                   ViInt32 window, ViInt32 trace,
                                                   ViInt32 finalDetector);
ViStatus _VI_FUNC rsesci_GetFinalReceiverDetector (ViSession instrSession,
                                                   ViInt32 window, ViInt32 trace,
                                                   ViPInt32 finalDetector);
ViStatus _VI_FUNC rsesci_PeakSearch (ViSession instrSession);
ViStatus _VI_FUNC rsesci_SetPeakSearchMethod (ViSession instrSession,
                                              ViInt32 searchMethod);
ViStatus _VI_FUNC rsesci_GetPeakSearchMethod (ViSession instrSession,
                                              ViPInt32 searchMethod);
ViStatus _VI_FUNC rsesci_SetPeakSearchMargin (ViSession instrSession,
                                              ViReal64 margin);
ViStatus _VI_FUNC rsesci_GetPeakSearchMargin (ViSession instrSession,
                                              ViPReal64 margin);
ViStatus _VI_FUNC rsesci_SetPeakSearchSubranges (ViSession instrSession,
                                                 ViInt32 subranges);
ViStatus _VI_FUNC rsesci_GetPeakSearchSubranges (ViSession instrSession,
                                                 ViPInt32 subranges);
ViStatus _VI_FUNC rsesci_SetPeakSearchListDisplay (ViSession instrSession,
                                                   ViInt32 window, ViInt32 trace,
                                                   ViInt32 indication);
ViStatus _VI_FUNC rsesci_GetPeakSearchListDisplay (ViSession instrSession,
                                                   ViInt32 window, ViInt32 trace,
                                                   ViPInt32 indication);
ViStatus _VI_FUNC rsesci_SetThresholdScan (ViSession instrSession,
                                           ViInt32 window, ViBoolean thresholdScan);
ViStatus _VI_FUNC rsesci_GetThresholdScan (ViSession instrSession,
                                           ViInt32 window,
                                           ViPBoolean thresholdScan);
ViStatus _VI_FUNC rsesci_SetNBBBDiscrimination (ViSession instrSession,
                                                ViInt32 window,
                                                ViBoolean discriminationState);
ViStatus _VI_FUNC rsesci_GetNBBBDiscrimination (ViSession instrSession,
                                                ViInt32 window,
                                                ViPBoolean discriminationState);
ViStatus _VI_FUNC rsesci_SetNBBBDiscriminationValue (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViReal64 discriminationThreshold);
ViStatus _VI_FUNC rsesci_GetNBBBDiscriminationValue (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViPReal64 discriminationThreshold);
ViStatus _VI_FUNC rsesci_SetFinalMeasurementTime (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViReal64 measurementTime);
ViStatus _VI_FUNC rsesci_GetFinalMeasurementTime (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViPReal64 measurementTime);
ViStatus _VI_FUNC rsesci_SetFinalMeasurementAuto (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViBoolean automaticMeasurement);
ViStatus _VI_FUNC rsesci_GetFinalMeasurementAuto (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViPBoolean automaticMeasurement);
ViStatus _VI_FUNC rsesci_SetVnetworkType (ViSession instrSession,
                                          ViInt32 window, ViInt32 measurement,
                                          ViInt32 vnetwork);
ViStatus _VI_FUNC rsesci_GetVnetworkType (ViSession instrSession,
                                          ViInt32 window, ViInt32 measurement,
                                          ViPInt32 vnetwork);
ViStatus _VI_FUNC rsesci_SetVnetworkProtectionEarth (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViInt32 measurement,
                                                     ViInt32 protectiveEarth);
ViStatus _VI_FUNC rsesci_GetVnetworkProtectionEarth (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViInt32 measurement,
                                                     ViPInt32 protectiveEarth);
ViStatus _VI_FUNC rsesci_SetVnetworkPhase (ViSession instrSession,
                                           ViInt32 window, ViInt32 measurement,
                                           ViInt32 phase);
ViStatus _VI_FUNC rsesci_GetVnetworkPhase (ViSession instrSession,
                                           ViInt32 window, ViInt32 measurement,
                                           ViPInt32 phase);
ViStatus _VI_FUNC rsesci_SetDemodulationType (ViSession instrSession,
                                              ViInt32 window, ViInt32 demodulation);
ViStatus _VI_FUNC rsesci_GetDemodulationType (ViSession instrSession,
                                              ViInt32 window,
                                              ViPInt32 demodulation);
ViStatus _VI_FUNC rsesci_ReadReceiverDetector (ViSession instrSession,
                                               ViPReal64 firstDetector,
                                               ViPReal64 secondDetector,
                                               ViPReal64 thirdDetector);
ViStatus _VI_FUNC rsesci_ReadReceiverDetectorPeakHold (ViSession instrSession,
                                                       ViReal64 _VI_FAR firstDetector[],
                                                       ViReal64 _VI_FAR secondDetector[],
                                                       ViReal64 _VI_FAR thirdDetector[]);
ViStatus _VI_FUNC rsesci_ReadScanMeasurement (ViSession instrSession,
                                              ViInt32 arraySize,
                                              ViPInt32 traceStatus,
                                              ViPInt32 number_ofResults,
                                              ViChar _VI_FAR statusData[],
                                              ViReal64 _VI_FAR results_ofTrace1[],
                                              ViReal64 _VI_FAR results_ofTrace2[],
                                              ViReal64 _VI_FAR results_ofTrace3[]);
ViStatus _VI_FUNC rsesci_ReadScanMeasurementStatus (ViSession instrSession,
                                                    ViInt32 arraySize,
                                                    ViPInt32 number_ofResults,
                                                    ViChar _VI_FAR statusData[]);
ViStatus _VI_FUNC rsesci_ReadFinalMeasurement (ViSession instrSession,
                                               ViInt32 trace, ViInt32 arraySize,
                                               ViPInt32 number_ofResults,
                                               ViReal64 _VI_FAR frequency[],
                                               ViReal64 _VI_FAR level[],
                                               ViReal64 _VI_FAR deltaLimit[]);
ViStatus _VI_FUNC rsesci_SetInstrumentMode (ViSession instrSession,
                                            ViInt32 instrumentMode);
ViStatus _VI_FUNC rsesci_GetInstrumentMode (ViSession instrSession,
                                            ViPInt32 instrumentMode);
ViStatus _VI_FUNC rsesci_SetMixedInstrumentMode (ViSession instrSession,
                                                 ViBoolean mixedMode,
                                                 ViInt32 screens);
ViStatus _VI_FUNC rsesci_GetMixedInstrumentMode (ViSession instrSession,
                                                 ViPBoolean mixedMode,
                                                 ViPInt32 screens);
ViStatus _VI_FUNC rsesci_SetTrackingGenerator (ViSession instrSession,
                                               ViInt32 window,
                                               ViBoolean trackingGenerator);
ViStatus _VI_FUNC rsesci_GetTrackingGenerator (ViSession instrSession,
                                               ViInt32 window,
                                               ViPBoolean trackingGenerator);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorSourcePower (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViReal64 outputLevel);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorSourcePower (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViPReal64 outputLevel);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorPowerOffset (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViReal64 levelOffset);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorPowerOffset (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViPReal64 levelOffset);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorFrequencyOffset
             (ViSession instrSession, ViInt32 window, ViReal64 frequencyOffset);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorFrequencyOffset
             (ViSession instrSession, ViInt32 window,
              ViPReal64 frequencyOffset);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorMeasurement (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViInt32 measurementType);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorMeasurement (ViSession instrSession,
                                                          ViInt32 window,
                                                          ViPInt32 measurementType);
ViStatus _VI_FUNC rsesci_SetTrackingGeneratorNormalization
             (ViSession instrSession, ViInt32 window, ViBoolean normalization);
ViStatus _VI_FUNC rsesci_GetTrackingGeneratorNormalization
             (ViSession instrSession, ViInt32 window, ViPBoolean normalization);
ViStatus _VI_FUNC rsesci_TrackingGeneratorCalibration (ViSession instrSession,
                                                       ViInt32 window,
                                                       ViInt32 acquisitionType);
ViStatus _VI_FUNC rsesci_TrackingGeneratorRecallSettings (ViSession instrSession,
                                                          ViInt32 window);
ViStatus _VI_FUNC rsesci_SetExternalAM (ViSession instrSession, ViInt32 window,
                                        ViBoolean externalAM);
ViStatus _VI_FUNC rsesci_GetExternalAM (ViSession instrSession, ViInt32 window,
                                        ViPBoolean externalAM);
ViStatus _VI_FUNC rsesci_SetExternalFM (ViSession instrSession, ViInt32 window,
                                        ViBoolean externalFM);
ViStatus _VI_FUNC rsesci_GetExternalFM (ViSession instrSession, ViInt32 window,
                                        ViPBoolean externalFM);
ViStatus _VI_FUNC rsesci_SetExternalIQModulation (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViBoolean IQModulation);
ViStatus _VI_FUNC rsesci_GetExternalIQModulation (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViPBoolean IQModulation);
ViStatus _VI_FUNC rsesci_SetExternalFMDeviation (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViReal64 FMDeviation);
ViStatus _VI_FUNC rsesci_GetExternalFMDeviation (ViSession instrSession,
                                                 ViInt32 window,
                                                 ViPReal64 FMDeviation);
ViStatus _VI_FUNC rsesci_SetExternalGenerator (ViSession instrSession,
                                               ViInt32 window,
                                               ViBoolean externalGenerator);
ViStatus _VI_FUNC rsesci_GetExternalGenerator (ViSession instrSession,
                                               ViInt32 window,
                                               ViPBoolean externalGenerator);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorSelection (ViSession instrSession,
                                                        ViInt32 generator,
                                                        ViInt32 intf,
                                                        ViString type,
                                                        ViInt32 GPIBAddress);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorSelection (ViSession instrSession,
                                                        ViInt32 generator,
                                                        ViPInt32 intf,
                                                        ViChar _VI_FAR type[],
                                                        ViPInt32 GPIBAddress);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorFrequencyOffset
             (ViSession instrSession, ViInt32 window, ViInt32 generator,
              ViReal64 offset);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorFrequencyOffset
             (ViSession instrSession, ViInt32 window, ViInt32 generator,
              ViPReal64 offset);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorMultiplicationFactor
             (ViSession instrSession, ViInt32 window, ViInt32 generator,
              ViInt32 numerator, ViInt32 denominator);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorMultiplicationFactor
             (ViSession instrSession, ViInt32 window, ViInt32 generator,
              ViPInt32 numerator, ViPInt32 denominator);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorFrequencySweep
             (ViSession instrSession, ViInt32 window, ViInt32 generator,
              ViBoolean sweep);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorFrequencySweep
             (ViSession instrSession, ViInt32 window, ViInt32 generator,
              ViPBoolean sweep);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorPower (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViInt32 generator,
                                                    ViReal64 power);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorPower (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViInt32 generator,
                                                    ViPReal64 power);
ViStatus _VI_FUNC rsesci_SetExternalGeneratorReferenceOscillator
             (ViSession instrSession, ViInt32 window, ViInt32 generator,
              ViInt32 referenceOscillator);
ViStatus _VI_FUNC rsesci_GetExternalGeneratorReferenceOscillator
             (ViSession instrSession, ViInt32 window, ViInt32 generator,
              ViPInt32 referenceOscillator);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulator (ViSession instrSession,
                                               ViBoolean analogDemodulator);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulator (ViSession instrSession,
                                               ViPBoolean analogDemodulator);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulatorParameters (ViSession instrSession,
                                                         ViReal64 sampleRate,
                                                         ViInt32 recordLength,
                                                         ViInt32 triggerSource,
                                                         ViInt32 triggerSlope,
                                                         ViInt32 offsetSamples,
                                                         ViInt32 number_ofMeas);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulatorParameters (ViSession instrSession,
                                                         ViPReal64 sampleRate,
                                                         ViPInt32 recordLength,
                                                         ViPInt32 triggerSource,
                                                         ViPInt32 triggerSlope,
                                                         ViPInt32 offsetSamples,
                                                         ViPInt32 number_ofMeas);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulatorResultDisplay
             (ViSession instrSession, ViInt32 resultDisplay, ViInt32 trace);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationMeasurementTime
             (ViSession instrSession, ViReal64 measurementTime);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationMeasurementTime
             (ViSession instrSession, ViPReal64 measurementTime);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationSampleRate (ViSession instrSession,
                                                          ViPReal64 sampleRate);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationRecordLength
             (ViSession instrSession, ViPReal64 recordLength);
ViStatus _VI_FUNC rsesci_SetAFCenterFrequency (ViSession instrSession,
                                               ViReal64 centerFrequency);
ViStatus _VI_FUNC rsesci_GetAFCenterFrequency (ViSession instrSession,
                                               ViPReal64 centerFrequency);
ViStatus _VI_FUNC rsesci_SetAFStartFrequency (ViSession instrSession,
                                              ViReal64 startFrequency);
ViStatus _VI_FUNC rsesci_GetAFStartFrequency (ViSession instrSession,
                                              ViPReal64 startFrequency);
ViStatus _VI_FUNC rsesci_SetAFStopFrequency (ViSession instrSession,
                                             ViReal64 stopFrequency);
ViStatus _VI_FUNC rsesci_GetAFStopFrequency (ViSession instrSession,
                                             ViPReal64 stopFrequency);
ViStatus _VI_FUNC rsesci_SetAFSpan (ViSession instrSession, ViReal64 span);
ViStatus _VI_FUNC rsesci_GetAFSpan (ViSession instrSession, ViPReal64 span);
ViStatus _VI_FUNC rsesci_SetRFFrequencySpan (ViSession instrSession,
                                             ViReal64 span);
ViStatus _VI_FUNC rsesci_GetRFFrequencySpan (ViSession instrSession,
                                             ViPReal64 span);
ViStatus _VI_FUNC rsesci_SetMaxRFFrequencySpan (ViSession instrSession,
                                                ViReal64 span);
ViStatus _VI_FUNC rsesci_GetMaxRFFrequencySpan (ViSession instrSession,
                                                ViPReal64 span);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationBandwidth (ViSession instrSession,
                                                         ViReal64 demodulationBandwidth);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationBandwidth (ViSession instrSession,
                                                         ViPReal64 demodulationBandwidth);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationResolutionBandwidth
             (ViSession instrSession, ViReal64 resolutionBandwidth);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationResolutionBandwidth
             (ViSession instrSession, ViPReal64 resolutionBandwidth);
ViStatus _VI_FUNC rsesci_SetAFInputCoupling (ViSession instrSession,
                                             ViInt32 AFInputCoupling);
ViStatus _VI_FUNC rsesci_GetAFInputCoupling (ViSession instrSession,
                                             ViPInt32 AFInputCoupling);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationAngleUnits (ViSession instrSession,
                                                          ViInt32 angleUnits);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationAngleUnits (ViSession instrSession,
                                                          ViPInt32 angleUnits);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationZoom (ViSession instrSession,
                                                    ViBoolean zoom);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationZoom (ViSession instrSession,
                                                    ViPBoolean zoom);
ViStatus _VI_FUNC rsesci_SetAnalogDemodulationZoomStart (ViSession instrSession,
                                                         ViReal64 zoomStart);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationZoomStart (ViSession instrSession,
                                                         ViPReal64 zoomStart);
ViStatus _VI_FUNC rsesci_GetFMModulationMeasurement (ViSession instrSession,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViInt32 trace,
                                                     ViInt32 measurement,
                                                     ViPReal64 result);
ViStatus _VI_FUNC rsesci_GetPMModulationMeasurement (ViSession instrSession,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViInt32 trace,
                                                     ViInt32 measurement,
                                                     ViPReal64 result);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationAudioFrequency
             (ViSession instrSession, ViInt32 window, ViInt32 marker,
              ViInt32 trace, ViPReal64 result);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationFrequencyError
             (ViSession instrSession, ViInt32 window, ViInt32 marker,
              ViInt32 trace, ViPReal64 result);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationSINAD (ViSession instrSession,
                                                     ViInt32 window, ViInt32 marker,
                                                     ViInt32 trace,
                                                     ViPReal64 result);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationTHD (ViSession instrSession,
                                                   ViInt32 window, ViInt32 marker,
                                                   ViInt32 trace, ViPReal64 result);
ViStatus _VI_FUNC rsesci_GetAnalogDemodulationCarrierPower
             (ViSession instrSession, ViInt32 window, ViInt32 marker,
              ViInt32 trace, ViPReal64 result);
ViStatus _VI_FUNC rsesci_SetAFSpectrumResultTypes (ViSession instrSession,
                                                   ViInt32 demodulationType,
                                                   ViInt32 resultType1,
                                                   ViInt32 resultType2,
                                                   ViInt32 resultType3);
ViStatus _VI_FUNC rsesci_GetAFSpectrumResultValues (ViSession instrSession,
                                                    ViInt32 demodulationType,
                                                    ViInt32 resultType,
                                                    ViInt32 arraySize,
                                                    ViPInt32 number_ofResults,
                                                    ViReal64 _VI_FAR results[]);
ViStatus _VI_FUNC rsesci_SetRFSpectrumResultTypes (ViSession instrSession,
                                                   ViInt32 resultType1,
                                                   ViInt32 resultType2,
                                                   ViInt32 resultType3);
ViStatus _VI_FUNC rsesci_GetRFSpectrumResultValues (ViSession instrSession,
                                                    ViInt32 resultType,
                                                    ViInt32 arraySize,
                                                    ViPInt32 number_ofResults,
                                                    ViReal64 _VI_FAR results[]);
ViStatus _VI_FUNC rsesci_SetTimeDomainResultTypes (ViSession instrSession,
                                                   ViInt32 demodulationType,
                                                   ViInt32 resultType1,
                                                   ViInt32 resultType2,
                                                   ViInt32 resultType3);
ViStatus _VI_FUNC rsesci_GetTimeDomainResultValues (ViSession instrSession,
                                                    ViInt32 demodulationType,
                                                    ViInt32 resultType,
                                                    ViInt32 arraySize,
                                                    ViPInt32 number_ofResults,
                                                    ViReal64 _VI_FAR results[]);
ViStatus _VI_FUNC rsesci_GetFMOffsetValue (ViSession instrSession,
                                           ViInt32 measurement, ViPReal64 result);
ViStatus _VI_FUNC rsesci_SetDataAveraging (ViSession instrSession,
                                           ViInt32 window, ViInt32 trace,
                                           ViBoolean dataAveraging);
ViStatus _VI_FUNC rsesci_GetDataAveraging (ViSession instrSession,
                                           ViInt32 window, ViInt32 trace,
                                           ViPBoolean dataAveraging);
ViStatus _VI_FUNC rsesci_SetAverageCount (ViSession instrSession,
                                          ViInt32 window, ViInt32 averageCount);
ViStatus _VI_FUNC rsesci_GetAverageCount (ViSession instrSession,
                                          ViInt32 window, ViPInt32 averageCount);
ViStatus _VI_FUNC rsesci_SetAverageType (ViSession instrSession, ViInt32 window,
                                         ViInt32 averageType);
ViStatus _VI_FUNC rsesci_GetAverageType (ViSession instrSession, ViInt32 window,
                                         ViPInt32 averageType);
ViStatus _VI_FUNC rsesci_SetLimitLineName (ViSession instrSession,
                                           ViInt32 limit, ViString name);
ViStatus _VI_FUNC rsesci_GetLimitLineName (ViSession instrSession,
                                           ViInt32 limit, ViChar _VI_FAR name[]);
ViStatus _VI_FUNC rsesci_SetLimitLineVisible (ViSession instrSession,
                                              ViInt32 window, ViInt32 limit,
                                              ViInt32 limitType, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetLimitLineVisible (ViSession instrSession,
                                              ViInt32 window, ViInt32 limit,
                                              ViInt32 limitType, ViPBoolean state);
ViStatus _VI_FUNC rsesci_SetLimitLineTrace (ViSession instrSession,
                                            ViInt32 window, ViInt32 limit,
                                            ViInt32 trace);
ViStatus _VI_FUNC rsesci_GetLimitLineTrace (ViSession instrSession,
                                            ViInt32 window, ViInt32 limit,
                                            ViPInt32 trace);
ViStatus _VI_FUNC rsesci_CopyLimitLine (ViSession instrSession,
                                        ViInt32 sourceLimit,
                                        ViInt32 destinationLimit);
ViStatus _VI_FUNC rsesci_DeleteLimitLine (ViSession instrSession,
                                          ViInt32 limit);
ViStatus _VI_FUNC rsesci_SetLimitLineXOffset (ViSession instrSession,
                                              ViInt32 window, ViInt32 limit,
                                              ViReal64 offset);
ViStatus _VI_FUNC rsesci_GetLimitLineXOffset (ViSession instrSession,
                                              ViInt32 window, ViInt32 limit,
                                              ViPReal64 offset);
ViStatus _VI_FUNC rsesci_SetLimitLineYOffset (ViSession instrSession,
                                              ViInt32 limit, ViInt32 limitType,
                                              ViReal64 offset);
ViStatus _VI_FUNC rsesci_GetLimitLineYOffset (ViSession instrSession,
                                              ViInt32 limit, ViInt32 limitType,
                                              ViPReal64 offset);
ViStatus _VI_FUNC rsesci_SetLimitLineCheck (ViSession instrSession,
                                            ViInt32 window, ViInt32 limit,
                                            ViBoolean limitCheck);
ViStatus _VI_FUNC rsesci_GetLimitLineCheck (ViSession instrSession,
                                            ViInt32 window, ViInt32 limit,
                                            ViPBoolean limitCheck);
ViStatus _VI_FUNC rsesci_GetLimitLineCheckResult (ViSession instrSession,
                                                  ViInt32 window, ViInt32 limit,
                                                  ViPInt32 result);
ViStatus _VI_FUNC rsesci_ClearLimitLineCheckResult (ViSession instrSession,
                                                    ViInt32 window);
ViStatus _VI_FUNC rsesci_SetLimitLineDomain (ViSession instrSession,
                                             ViInt32 window, ViInt32 limit,
                                             ViInt32 domain);
ViStatus _VI_FUNC rsesci_GetLimitLineDomain (ViSession instrSession,
                                             ViInt32 window, ViInt32 limit,
                                             ViPInt32 domain);
ViStatus _VI_FUNC rsesci_SetLimitLineInterpolation (ViSession instrSession,
                                                    ViInt32 window, ViInt32 limit,
                                                    ViInt32 interpolationAxis,
                                                    ViInt32 interpolation);
ViStatus _VI_FUNC rsesci_GetLimitLineInterpolation (ViSession instrSession,
                                                    ViInt32 window, ViInt32 limit,
                                                    ViInt32 interpolationAxis,
                                                    ViPInt32 interpolation);
ViStatus _VI_FUNC rsesci_SetLimitLineScaling (ViSession instrSession,
                                              ViInt32 limit,
                                              ViInt32 interpolationAxis,
                                              ViInt32 limitLineScaling);
ViStatus _VI_FUNC rsesci_GetLimitLineScaling (ViSession instrSession,
                                              ViInt32 limit,
                                              ViInt32 interpolationAxis,
                                              ViPInt32 limitLineScaling);
ViStatus _VI_FUNC rsesci_SetLimitLineUnit (ViSession instrSession,
                                           ViInt32 limit, ViInt32 levelAxisUnit);
ViStatus _VI_FUNC rsesci_GetLimitLineUnit (ViSession instrSession,
                                           ViInt32 limit, ViPInt32 levelAxisUnit);
ViStatus _VI_FUNC rsesci_SetLimitLineMargin (ViSession instrSession,
                                             ViInt32 limit, ViInt32 limitLineType,
                                             ViReal64 margin);
ViStatus _VI_FUNC rsesci_GetLimitLineMargin (ViSession instrSession,
                                             ViInt32 limit, ViInt32 limitLineType,
                                             ViPReal64 margin);
ViStatus _VI_FUNC rsesci_SetLimitLineThreshold (ViSession instrSession,
                                                ViInt32 limit,
                                                ViInt32 limitLineType,
                                                ViReal64 threshold);
ViStatus _VI_FUNC rsesci_GetLimitLineThreshold (ViSession instrSession,
                                                ViInt32 limit,
                                                ViInt32 limitLineType,
                                                ViPReal64 threshold);
ViStatus _VI_FUNC rsesci_SetLimitLineComment (ViSession instrSession,
                                              ViInt32 limit, ViString comment);
ViStatus _VI_FUNC rsesci_GetLimitLineComment (ViSession instrSession,
                                              ViInt32 limit,
                                              ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsesci_SetLimitLineValues (ViSession instrSession,
                                             ViInt32 limit, ViInt32 axis,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR data[]);
ViStatus _VI_FUNC rsesci_GetLimitLineValues (ViSession instrSession,
                                             ViInt32 limit, ViInt32 axis,
                                             ViInt32 arraySize,
                                             ViReal64 _VI_FAR data[]);
ViStatus _VI_FUNC rsesci_LimitLineShiftX (ViSession instrSession, ViInt32 limit,
                                          ViReal64 shift);
ViStatus _VI_FUNC rsesci_LimitLineShiftY (ViSession instrSession, ViInt32 limit,
                                          ViInt32 axisType, ViReal64 shift);
ViStatus _VI_FUNC rsesci_SetDisplayLine (ViSession instrSession, ViInt32 window,
                                         ViInt32 line, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetDisplayLine (ViSession instrSession, ViInt32 window,
                                         ViInt32 line, ViPBoolean state);
ViStatus _VI_FUNC rsesci_SetDisplayLinePosition (ViSession instrSession,
                                                 ViInt32 window, ViInt32 line,
                                                 ViReal64 position);
ViStatus _VI_FUNC rsesci_GetDisplayLinePosition (ViSession instrSession,
                                                 ViInt32 window, ViInt32 line,
                                                 ViPReal64 position);
ViStatus _VI_FUNC rsesci_SetFrequencyLine (ViSession instrSession,
                                           ViInt32 window, ViInt32 line,
                                           ViBoolean state);
ViStatus _VI_FUNC rsesci_GetFrequencyLine (ViSession instrSession,
                                           ViInt32 window, ViInt32 line,
                                           ViPBoolean state);
ViStatus _VI_FUNC rsesci_SetFrequencyLinePosition (ViSession instrSession,
                                                   ViInt32 window, ViInt32 line,
                                                   ViReal64 position);
ViStatus _VI_FUNC rsesci_GetFrequencyLinePosition (ViSession instrSession,
                                                   ViInt32 window, ViInt32 line,
                                                   ViPReal64 position);
ViStatus _VI_FUNC rsesci_SetTimeLine (ViSession instrSession, ViInt32 window,
                                      ViInt32 line, ViBoolean state);
ViStatus _VI_FUNC rsesci_GetTimeLine (ViSession instrSession, ViInt32 window,
                                      ViInt32 line, ViPBoolean state);
ViStatus _VI_FUNC rsesci_SetTimeLinePosition (ViSession instrSession,
                                              ViInt32 window, ViInt32 line,
                                              ViReal64 position);
ViStatus _VI_FUNC rsesci_GetTimeLinePosition (ViSession instrSession,
                                              ViInt32 window, ViInt32 line,
                                              ViPReal64 position);
ViStatus _VI_FUNC rsesci_SetActiveWindow (ViSession instrSession,
                                          ViInt32 window);
ViStatus _VI_FUNC rsesci_SetScreenMode (ViSession instrSession, ViInt32 mode);
ViStatus _VI_FUNC rsesci_GetScreenMode (ViSession instrSession, ViPInt32 mode);
ViStatus _VI_FUNC rsesci_SetDisplaySize (ViSession instrSession,
                                         ViInt32 displaySize);
ViStatus _VI_FUNC rsesci_GetDisplaySize (ViSession instrSession,
                                         ViPInt32 displaySize);
ViStatus _VI_FUNC rsesci_SetDisplayUpdate (ViSession instrSession,
                                           ViBoolean displayUpdate);
ViStatus _VI_FUNC rsesci_GetDisplayUpdate (ViSession instrSession,
                                           ViPBoolean displayUpdate);
ViStatus _VI_FUNC rsesci_SetDisplayBargraphMaxhold (ViSession instrSession,
                                                    ViBoolean bargraphMaxhold);
ViStatus _VI_FUNC rsesci_GetDisplayBargraphMaxhold (ViSession instrSession,
                                                    ViPBoolean bargraphMaxhold);
ViStatus _VI_FUNC rsesci_GetDisplayBargraphLevel (ViSession instrSession,
                                                  ViPReal64 minimumBargraphLevel,
                                                  ViPReal64 maximumBargraphLevel);
ViStatus _VI_FUNC rsesci_ResetDisplayBargraphMaxhold (ViSession instrSession);
ViStatus _VI_FUNC rsesci_SetParameterCoupling (ViSession instrSession,
                                               ViInt32 coupledParameters,
                                               ViBoolean coupling);
ViStatus _VI_FUNC rsesci_GetParameterCoupling (ViSession instrSession,
                                               ViInt32 coupledParameters,
                                               ViPBoolean coupling);
ViStatus _VI_FUNC rsesci_SetInstrumentCoupling (ViSession instrSession,
                                                ViInt32 coupling);
ViStatus _VI_FUNC rsesci_SetScreenTitle (ViSession instrSession,
                                         ViBoolean screenTitle,
                                         ViString commentString);
ViStatus _VI_FUNC rsesci_SetDisplayElements (ViSession instrSession,
                                             ViBoolean annotation, ViBoolean logo,
                                             ViBoolean timeDate);
ViStatus _VI_FUNC rsesci_SetDisplayUserDefinedColors (ViSession instrSession,
                                                      ViInt32 colorMap,
                                                      ViInt32 predefinedColors,
                                                      ViReal64 tint,
                                                      ViReal64 saturation,
                                                      ViReal64 brightness);
ViStatus _VI_FUNC rsesci_SetDisplayDefaultColors (ViSession instrSession,
                                                  ViInt32 defaultColors);
ViStatus _VI_FUNC rsesci_SetDisplayPowerSaving (ViSession instrSession,
                                                ViBoolean powerSaving,
                                                ViInt32 holdoffTime);
ViStatus _VI_FUNC rsesci_SetExternalReferenceOscillator (ViSession instrSession,
                                                         ViInt32 referenceOscillator);
ViStatus _VI_FUNC rsesci_GetExternalReferenceOscillator (ViSession instrSession,
                                                         ViPInt32 referenceOscillator);
ViStatus _VI_FUNC rsesci_SetExternalNoiseSource (ViSession instrSession,
                                                 ViBoolean noiseSource);
ViStatus _VI_FUNC rsesci_GetExternalNoiseSource (ViSession instrSession,
                                                 ViPBoolean noiseSource);
ViStatus _VI_FUNC rsesci_SetPreselector (ViSession instrSession,
                                         ViBoolean preselector);
ViStatus _VI_FUNC rsesci_GetPreselector (ViSession instrSession,
                                         ViPBoolean preselector);
ViStatus _VI_FUNC rsesci_SetTransducerFactor (ViSession instrSession,
                                              ViInt32 window,
                                              ViBoolean transducerFactor);
ViStatus _VI_FUNC rsesci_GetTransducerFactor (ViSession instrSession,
                                              ViInt32 window,
                                              ViPBoolean transducerFactor);
ViStatus _VI_FUNC rsesci_SetTransducerFactorName (ViSession instrSession,
                                                  ViInt32 window, ViString name);
ViStatus _VI_FUNC rsesci_GetTransducerFactorName (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViChar _VI_FAR name[]);
ViStatus _VI_FUNC rsesci_DeleteTransducerFactor (ViSession instrSession,
                                                 ViInt32 window, ViString name);
ViStatus _VI_FUNC rsesci_SetTransducerFactorView (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViBoolean transducerFactorView);
ViStatus _VI_FUNC rsesci_GetTransducerFactorView (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViPBoolean transducerFactorView);
ViStatus _VI_FUNC rsesci_SetTransducerFactorAutoAdjust (ViSession instrSession,
                                                        ViInt32 window,
                                                        ViBoolean autoAdjust);
ViStatus _VI_FUNC rsesci_GetTransducerFactorAutoAdjust (ViSession instrSession,
                                                        ViInt32 window,
                                                        ViPBoolean autoAdjust);
ViStatus _VI_FUNC rsesci_SetTransducerSet (ViSession instrSession,
                                           ViInt32 window, ViBoolean transducerSet);
ViStatus _VI_FUNC rsesci_GetTransducerSet (ViSession instrSession,
                                           ViInt32 window,
                                           ViPBoolean transducerSet);
ViStatus _VI_FUNC rsesci_SetTransducerSetName (ViSession instrSession,
                                               ViInt32 window, ViString name);
ViStatus _VI_FUNC rsesci_GetTransducerSetName (ViSession instrSession,
                                               ViInt32 window,
                                               ViChar _VI_FAR name[]);
ViStatus _VI_FUNC rsesci_DeleteTransducerSet (ViSession instrSession,
                                              ViInt32 window, ViString name);
ViStatus _VI_FUNC rsesci_SetTransducerFactorUnit (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViInt32 transducerFactorUnit);
ViStatus _VI_FUNC rsesci_GetTransducerFactorUnit (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViPInt32 transducerFactorUnit);
ViStatus _VI_FUNC rsesci_SetTransducerFactorInterpolation
             (ViSession instrSession, ViInt32 window,
              ViInt32 transducerFactorInterpolation);
ViStatus _VI_FUNC rsesci_GetTransducerFactorInterpolation
             (ViSession instrSession, ViInt32 window,
              ViPInt32 transducerFactorInterpolation);
ViStatus _VI_FUNC rsesci_SetTransducerFactorComment (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViString comment);
ViStatus _VI_FUNC rsesci_GetTransducerFactorComment (ViSession instrSession,
                                                     ViInt32 window,
                                                     ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsesci_SetTransducerFactorValues (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViInt32 arraySize,
                                                    ViReal64 _VI_FAR frequencyValues[],
                                                    ViReal64 _VI_FAR levelValues[]);
ViStatus _VI_FUNC rsesci_GetTransducerFactorValues (ViSession instrSession,
                                                    ViInt32 window,
                                                    ViPInt32 number_ofResults,
                                                    ViReal64 _VI_FAR frequencyValues[],
                                                    ViReal64 _VI_FAR levelValues[]);
ViStatus _VI_FUNC rsesci_SetTransducerSetUnit (ViSession instrSession,
                                               ViInt32 window,
                                               ViInt32 transducerSetUnit);
ViStatus _VI_FUNC rsesci_GetTransducerSetUnit (ViSession instrSession,
                                               ViInt32 window,
                                               ViPInt32 transducerSetUnit);
ViStatus _VI_FUNC rsesci_SetTransducerSetBreak (ViSession instrSession,
                                                ViInt32 window,
                                                ViBoolean transducerSetBreak);
ViStatus _VI_FUNC rsesci_GetTransducerSetBreak (ViSession instrSession,
                                                ViInt32 window,
                                                ViPBoolean transducerSetBreak);
ViStatus _VI_FUNC rsesci_SetTransducerSetComment (ViSession instrSession,
                                                  ViInt32 window, ViString comment);
ViStatus _VI_FUNC rsesci_GetTransducerSetComment (ViSession instrSession,
                                                  ViInt32 window,
                                                  ViChar _VI_FAR comment[]);
ViStatus _VI_FUNC rsesci_SetTransducerSetValues (ViSession instrSession,
                                                 ViInt32 window, ViInt32 range,
                                                 ViReal64 startFrequency,
                                                 ViReal64 stopFrequency,
                                                 ViString factors);
ViStatus _VI_FUNC rsesci_GetTransducerSetValues (ViSession instrSession,
                                                 ViInt32 window, ViInt32 range,
                                                 ViPReal64 startFrequency,
                                                 ViPReal64 stopFrequency,
                                                 ViChar _VI_FAR factors[]);
ViStatus _VI_FUNC rsesci_SetGPIBAddress (ViSession instrSession,
                                         ViInt32 GPIBAddress);
ViStatus _VI_FUNC rsesci_GetGPIBAddress (ViSession instrSession,
                                         ViPInt32 GPIBAddress);
ViStatus _VI_FUNC rsesci_SetSerialInterfaceConfiguration (ViSession instrSession,
                                                          ViInt32 baudRate,
                                                          ViInt32 dataBits,
                                                          ViInt32 stopBits,
                                                          ViBoolean hardwareHandshake,
                                                          ViBoolean softwareHandshake,
                                                          ViInt32 parity);
ViStatus _VI_FUNC rsesci_GetSerialInterfaceConfiguration (ViSession instrSession,
                                                          ViPInt32 baudRate,
                                                          ViPInt32 dataBits,
                                                          ViPInt32 stopBits,
                                                          ViPBoolean hardwareHandshake,
                                                          ViPBoolean softwareHandshake,
                                                          ViPInt32 parity);
ViStatus _VI_FUNC rsesci_SetSystemTime (ViSession instrSession, ViInt32 hour,
                                        ViInt32 minute, ViInt32 second);
ViStatus _VI_FUNC rsesci_GetSystemTime (ViSession instrSession, ViPInt32 hour,
                                        ViPInt32 minute, ViPInt32 second);
ViStatus _VI_FUNC rsesci_SetSystemDate (ViSession instrSession, ViInt32 day,
                                        ViInt32 month, ViInt32 year);
ViStatus _VI_FUNC rsesci_GetSystemDate (ViSession instrSession, ViPInt32 day,
                                        ViPInt32 month, ViPInt32 year);
ViStatus _VI_FUNC rsesci_SetSpeakerVolume (ViSession instrSession,
                                           ViReal64 speakerVolume);
ViStatus _VI_FUNC rsesci_GetSpeakerVolume (ViSession instrSession,
                                           ViPReal64 speakerVolume);
ViStatus _VI_FUNC rsesci_SetSoftFrontpanel (ViSession instrSession,
                                            ViBoolean softFrontpanel);
ViStatus _VI_FUNC rsesci_GetSoftFrontpanel (ViSession instrSession,
                                            ViPBoolean softFrontpanel);
ViStatus _VI_FUNC rsesci_SetUserPort (ViSession instrSession, ViInt32 userPort);
ViStatus _VI_FUNC rsesci_GetUserPort (ViSession instrSession,
                                      ViPInt32 userPort);
ViStatus _VI_FUNC rsesci_ReadUserPortValue (ViSession instrSession,
                                            ViBoolean _VI_FAR userPortValue[]);
ViStatus _VI_FUNC rsesci_WriteUserPortValue (ViSession instrSession,
                                             ViBoolean _VI_FAR userPortValue[]);
ViStatus _VI_FUNC rsesci_SetServiceSource (ViSession instrSession,
                                           ViInt32 window, ViInt32 serviceSource,
                                           ViReal64 calibrationSourceLevel);
ViStatus _VI_FUNC rsesci_GetServiceSource (ViSession instrSession,
                                           ViInt32 window, ViPInt32 serviceSource,
                                           ViPReal64 calibrationSourceLevel);
ViStatus _VI_FUNC rsesci_SetServicePulseGenerator (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViBoolean pulseGenerator,
                                                   ViReal64 pulseRate);
ViStatus _VI_FUNC rsesci_GetServicePulseGenerator (ViSession instrSession,
                                                   ViInt32 window,
                                                   ViPBoolean pulseGenerator,
                                                   ViPReal64 pulseRate);
ViStatus _VI_FUNC rsesci_FirmwareUpdate (ViSession instrSession, ViString path);
ViStatus _VI_FUNC rsesci_CompatibilityMode (ViSession instrSession,
                                            ViInt32 compatibilityMode);
ViStatus _VI_FUNC rsesci_DataSetSave (ViSession instrSession, ViString fileName,
                                      ViString comment);
ViStatus _VI_FUNC rsesci_DataSetRecall (ViSession instrSession,
                                        ViString fileName);
ViStatus _VI_FUNC rsesci_DataSetRecallAuto (ViSession instrSession,
                                            ViString fileName);
ViStatus _VI_FUNC rsesci_DataSetItems (ViSession instrSession,
                                       ViInt32 dataSetItems,
                                       ViBoolean selectedItem);
ViStatus _VI_FUNC rsesci_DataSetCatalog (ViSession instrSession,
                                         ViString directory,
                                         ViChar _VI_FAR catalog[],
                                         ViInt32 bufferSize);
ViStatus _VI_FUNC rsesci_DataSetClear (ViSession instrSession, ViInt32 clear,
                                       ViString path);
ViStatus _VI_FUNC rsesci_FileManager (ViSession instrSession,
                                      ViInt32 operation_to_bePerformed,
                                      ViString source, ViString destination);
ViStatus _VI_FUNC rsesci_readToFile (ViSession instrSession, ViString source,
                                     ViString destination);
ViStatus _VI_FUNC rsesci_writeFromFile (ViSession instrSession, ViString source,
                                        ViString destination);
ViStatus _VI_FUNC rsesci_StoreTraceData (ViSession instrSession, ViInt32 trace,
                                         ViString fileName);
ViStatus _VI_FUNC rsesci_StoreFinalMeasurementData (ViSession instrSession,
                                                    ViString fileName);
ViStatus _VI_FUNC rsesci_SetDecimalPointNotation (ViSession instrSession,
                                                  ViInt32 decimalSeparator);
ViStatus _VI_FUNC rsesci_GetDecimalPointNotation (ViSession instrSession,
                                                  ViPInt32 decimalSeparator);
ViStatus _VI_FUNC rsesci_SelectPrinter (ViSession instrSession,
                                        ViInt32 deviceNumber, ViString printerName);
ViStatus _VI_FUNC rsesci_QueryPrinterList (ViSession instrSession,
                                           ViChar _VI_FAR printerList[]);
ViStatus _VI_FUNC rsesci_AbortHardcopy (ViSession instrSession);
ViStatus _VI_FUNC rsesci_InitiateHardcopy (ViSession instrSession,
                                           ViInt32 deviceNumber);
ViStatus _VI_FUNC rsesci_HardcopyDeviceSetup (ViSession instrSession,
                                              ViInt32 deviceNumber,
                                              ViInt32 destination,
                                              ViInt32 dataFormat,
                                              ViInt32 pageOrientation,
                                              ViString fileName);
ViStatus _VI_FUNC rsesci_HardcopyComment (ViSession instrSession,
                                          ViInt32 window, ViString comment);
ViStatus _VI_FUNC rsesci_HardcopyItems (ViSession instrSession, ViInt32 window,
                                        ViInt32 hardcopyItems);
ViStatus _VI_FUNC rsesci_HardcopyColor (ViSession instrSession,
                                        ViBoolean color);
ViStatus _VI_FUNC rsesci_HardcopyUserDefinedColors (ViSession instrSession,
                                                    ViInt32 colorMap,
                                                    ViInt32 predefinedColors,
                                                    ViReal64 tint,
                                                    ViReal64 saturation,
                                                    ViReal64 brightness);
ViStatus _VI_FUNC rsesci_HardcopyDefaultColors (ViSession instrSession,
                                                ViInt32 defaultColors);
ViStatus _VI_FUNC rsesci_InitiateHardcopyToFile (ViSession instrumentHandle,
                                                 ViInt32 deviceNumber,
                                                 ViString destination,
                                                 ViInt32 dataFormat,
                                                 ViInt32 pageOrientation);
ViStatus _VI_FUNC rsesci_errorCheckState (ViSession instrSession,
                                          ViBoolean stateChecking);
ViStatus _VI_FUNC rsesci_setStatusRegister (ViSession instrSession,
                                            ViInt32 registerOperation,
                                            ViInt32 questionableRegister,
                                            ViInt32 enable, ViInt32 PTransition,
                                            ViInt32 NTransition);
ViStatus _VI_FUNC rsesci_getStatusRegister (ViSession instrSession,
                                            ViInt32 statusRegistersQuery,
                                            ViPInt32 registerValue);
ViStatus _VI_FUNC rsesci_writeInstrData (ViSession instrSession,
                                         ViString writeBuffer);
ViStatus _VI_FUNC rsesci_readInstrData (ViSession instrSession,
                                        ViInt32 numberBytesToRead,
                                        ViChar _VI_FAR readBuffer[],
                                        ViPInt32 numBytesRead);
ViStatus _VI_FUNC rsesci_reset (ViSession instrSession);
ViStatus _VI_FUNC rsesci_self_test (ViSession instrSession,
                                    ViPInt16 selfTestResult,
                                    ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rsesci_error_query (ViSession instrSession,
                                      ViPInt32 errorCode,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rsesci_error_message (ViSession instrSession,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rsesci_revision_query (ViSession instrSession,
                                         ViChar _VI_FAR instrumentDriverRevision[],
                                         ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rsesci_close (ViSession instrSession);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
